@@ -3,8 +3,7 @@
 import numpy as np
 import pylab as pl
 
-from nipy.labs.utils.simul_multisubject_fmri_dataset import \
-     surrogate_2d_dataset
+from nipy.labs.utils.simul_multisubject_fmri_dataset import surrogate_2d_dataset
 
 pos = np.array([[10, 10],
                 [14, 20],
@@ -13,7 +12,7 @@ ampli = np.array([4, 5, 2])
 
 # First generate some noiseless data
 noiseless_data = surrogate_2d_dataset(n_subj=1, noise_level=0, spatial_jitter=0,
-                                signal_jitter=0, pos=pos, ampli=ampli)
+                                      signal_jitter=0, pos=pos, ampli=ampli)
 
 pl.figure(figsize=(10, 3))
 pl.subplot(1, 4, 1)
