@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function # Python 2/3 compatibility
 __doc__ = """
 Example of a demo that fits a Gaussian Mixture Model (GMM) to  a dataset The
 possible number of clusters is in the [1,10] range The proposed algorithm
@@ -20,7 +19,7 @@ try:
 except ImportError:
     raise RuntimeError("This script needs the matplotlib library")
 
-import nipy.algorithms.clustering.gmm as gmm
+from nipy.algorithms.clustering import gmm
 
 dim = 2
 # 1. generate a 3-components mixture
