@@ -19,33 +19,33 @@ to some of these analyses.
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
-from __future__ import print_function # Python 2/3 compatibility
 
 # Stdlib
-from tempfile import NamedTemporaryFile
-from os.path import join as pjoin
-from copy import copy
 import warnings
+from copy import copy
+
+# While developing interactively:
+from imp import reload
+from os.path import join as pjoin
+from tempfile import NamedTemporaryFile
+
+# Local
+import ds105_util as futil
 
 # Third party
 import numpy as np
 
+from nipy.algorithms.statistics import onesample
+
 # From NIPY
-from nipy.algorithms.statistics.api import (OLSModel, ARModel, make_recarray,
-                                            isestimable)
-from nipy.modalities.fmri.fmristat import hrf as delay
-from nipy.modalities.fmri import design
-from nipy.io.api import load_image, save_image
+from nipy.algorithms.statistics.api import ARModel, OLSModel, isestimable, make_recarray
 from nipy.core import api
 from nipy.core.api import Image
 from nipy.core.image.image import rollimg
+from nipy.io.api import load_image, save_image
+from nipy.modalities.fmri import design
+from nipy.modalities.fmri.fmristat import hrf as delay
 
-from nipy.algorithms.statistics import onesample
-
-# Local
-import ds105_util as futil
-# While developing interactively:
-from imp import reload
 reload(futil)
 
 #-----------------------------------------------------------------------------
@@ -63,7 +63,7 @@ CONTRASTS = ('speaker_0', 'speaker_1',
 # XXX: this mask was copied by hand from one of the subjects
 # we should have a function to create this mask from the ds105 data
 GROUP_MASK = futil.load_image_ds105('group', 'mask.nii.gz')
-TINY_MASK = np.zeros(GROUP_MASK.shape, np.bool)
+TINY_MASK = np.zeros(GROUP_MASK.shape, np.bool_)
 TINY_MASK[30:32,40:42,30:32] = 1
 
 #-----------------------------------------------------------------------------
@@ -160,16 +160,16 @@ def run_model(subj, run):
                                    (drift, {}))
 
     # Sanity check: delete any non-estimable contrasts
-    for k in cons.keys():
+    for k in cons:
         if not isestimable(cons[k], X):
             del(cons[k])
-            warnings.warn("contrast %s not estimable for this run" % k)
+            warnings.warn(f"contrast {k} not estimable for this run")
 
     # The default contrasts are all t-statistics.  We may want to output
     # F-statistics for 'speaker', 'sentence', 'speaker:sentence' based on the
     # two coefficients, one for each HRF in delay.spectral
 
-    # We reproduce the same constrasts as in the data base
+    # We reproduce the same contrasts as in the data base
     # outputting an F using both HRFs, as well as the
     # t using only the first HRF
 
@@ -177,15 +177,15 @@ def run_model(subj, run):
                        ('house', 'scrambled'),
                        ('chair', 'scrambled'),
                        ('face', 'house')]:
-        cons['%s_vs_%s_F' % (obj1, obj2)] = \
-            np.vstack([cons['object_%s_0' % obj1] - 
-                       cons['object_%s_0' % obj2],
-                       cons['object_%s_1' % obj1] - 
-                       cons['object_%s_1' % obj2]])
+        cons[f'{obj1}_vs_{obj2}_F'] = \
+            np.vstack([cons[f'object_{obj1}_0'] -
+                       cons[f'object_{obj2}_0'],
+                       cons[f'object_{obj1}_1'] -
+                       cons[f'object_{obj2}_1']])
 
 
-        cons['%s_vs_%s_t' % (obj1, obj2)] = (cons['object_%s_0' % obj1] - 
-                                             cons['object_%s_0' % obj2])
+        cons[f'{obj1}_vs_{obj2}_t'] = (cons[f'object_{obj1}_0'] -
+                                             cons[f'object_{obj2}_0'])
 
     #----------------------------------------------------------------------
     # Data loading
@@ -195,7 +195,7 @@ def run_model(subj, run):
     # time as the first dimension, i.e. fmri[t] gives the t-th volume.
     fmri_im = futil.get_fmri(path_info) # an Image
     fmri_im = rollimg(fmri_im, 't')
-    fmri = fmri_im.get_data() # now, it's an ndarray
+    fmri = fmri_im.get_fdata() # now, it's an ndarray
 
     nvol, volshape = fmri.shape[0], fmri.shape[1:]
     nx, sliceshape = volshape[0], volshape[1:]
@@ -224,7 +224,7 @@ def run_model(subj, run):
     # XXX smooth here?
     # ar1 = smooth(ar1, 8.0)
     ar1 *= 100
-    ar1 = ar1.astype(np.int) / 100.
+    ar1 = ar1.astype(np.int_) / 100.
 
     # We split the contrasts into F-tests and t-tests.
     # XXX helper function should do this
@@ -242,14 +242,12 @@ def run_model(subj, run):
     for n in tcons:
         tempdict = {}
         for v in ['sd', 't', 'effect']:
-            tempdict[v] = np.memmap(NamedTemporaryFile(prefix='%s%s.nii'
-                                    % (n,v)), dtype=np.float,
+            tempdict[v] = np.memmap(NamedTemporaryFile(prefix=f'{n}{v}.nii'), dtype=np.float64,
                                     shape=volshape, mode='w+')
         output[n] = tempdict
 
     for n in fcons:
-        output[n] = np.memmap(NamedTemporaryFile(prefix='%s%s.nii'
-                                    % (n,v)), dtype=np.float,
+        output[n] = np.memmap(NamedTemporaryFile(prefix=f'{n}{v}.nii'), dtype=np.float64,
                                     shape=volshape, mode='w+')
 
     # Loop over the unique values of ar1
@@ -275,7 +273,7 @@ def run_model(subj, run):
     for n in tcons:
         for v in ['t', 'sd', 'effect']:
             im = Image(output[n][v], vol0_map)
-            save_image(im, pjoin(odir, n, '%s.nii' % v))
+            save_image(im, pjoin(odir, n, f'{v}.nii'))
     for n in fcons:
         im = Image(output[n], vol0_map)
         save_image(im, pjoin(odir, n, "F.nii"))
@@ -310,8 +308,8 @@ def fixed_effects(subj, design):
         fixed_effect = 0
         fixed_var = 0
         for effect, sd in results[con]:
-            effect = load_image(effect).get_data()
-            sd = load_image(sd).get_data()
+            effect = load_image(effect).get_fdata()
+            sd = load_image(sd).get_fdata()
             var = sd ** 2
 
             # The optimal, in terms of minimum variance, combination of the
@@ -333,7 +331,7 @@ def fixed_effects(subj, design):
         for a, n in zip([fixed_effect, fixed_sd, fixed_t],
                         ['effect', 'sd', 't']):
             im = api.Image(a, copy(coordmap))
-            save_image(im, pjoin(odir, '%s.nii' % n))
+            save_image(im, pjoin(odir, f'{n}.nii'))
 
 
 def group_analysis(design, contrast):
@@ -354,7 +352,7 @@ def group_analysis(design, contrast):
     # Which subjects have this (contrast, design) pair?
     subj_con_dirs = futil.subj_des_con_dirs(design, contrast)
     if len(subj_con_dirs) == 0:
-        raise ValueError('No subjects for %s, %s' % (design, contrast))
+        raise ValueError(f'No subjects for {design}, {contrast}')
 
     # Assemble effects and sds into 4D arrays
     sds = []
@@ -362,8 +360,8 @@ def group_analysis(design, contrast):
     for s in subj_con_dirs:
         sd_img = load_image(pjoin(s, "sd.nii"))
         effect_img = load_image(pjoin(s, "effect.nii"))
-        sds.append(sd_img.get_data())
-        Ys.append(effect_img.get_data())
+        sds.append(sd_img.get_fdata())
+        Ys.append(effect_img.get_fdata())
     sd = array(sds)
     Y = array(Ys)
 
@@ -392,10 +390,10 @@ def group_analysis(design, contrast):
     adjusted_var = sd**2 + random_var
     adjusted_sd = np.sqrt(adjusted_var)
 
-    results = onesample.estimate_mean(Y, adjusted_sd) 
+    results = onesample.estimate_mean(Y, adjusted_sd)
     for n in ['effect', 'sd', 't']:
         im = api.Image(results[n], copy(coordmap))
-        save_image(im, pjoin(odir, "%s.nii" % n))
+        save_image(im, pjoin(odir, f"{n}.nii"))
 
 
 def group_analysis_signs(design, contrast, mask, signs=None):
@@ -424,10 +422,10 @@ def group_analysis_signs(design, contrast, mask, signs=None):
          vector of signs
     """
     if api.is_image(mask):
-        maska = mask.get_data()
+        maska = mask.get_fdata()
     else:
         maska = np.asarray(mask)
-    maska = maska.astype(np.bool)
+    maska = maska.astype(np.bool_)
 
     # Which subjects have this (contrast, design) pair?
     subj_con_dirs = futil.subj_des_con_dirs(design, contrast)
@@ -438,8 +436,8 @@ def group_analysis_signs(design, contrast, mask, signs=None):
     for s in subj_con_dirs:
         sd_img = load_image(pjoin(s, "sd.nii"))
         effect_img = load_image(pjoin(s, "effect.nii"))
-        sds.append(sd_img.get_data()[maska])
-        Ys.append(effect_img.get_data()[maska])
+        sds.append(sd_img.get_fdata()[maska])
+        Ys.append(effect_img.get_fdata()[maska])
     sd = np.array(sds)
     Y = np.array(Ys)
 
@@ -457,7 +455,7 @@ def group_analysis_signs(design, contrast, mask, signs=None):
         adjusted_var = sd**2 + random_var
         adjusted_sd = np.sqrt(adjusted_var)
 
-        results = onesample.estimate_mean(Y, adjusted_sd) 
+        results = onesample.estimate_mean(Y, adjusted_sd)
         T = results['t']
         minT[i], maxT[i] = np.nanmin(T), np.nanmax(T)
     return minT, maxT
@@ -488,7 +486,7 @@ def permutation_test(design, contrast, mask=GROUP_MASK, nsample=1000):
     subj_con_dirs = futil.subj_des_con_dirs(design, contrast)
     nsubj = len(subj_con_dirs)
     if nsubj == 0:
-        raise ValueError('No subjects have %s, %s' % (design, contrast))
+        raise ValueError(f'No subjects have {design}, {contrast}')
     signs = 2*np.greater(np.random.sample(size=(nsample, nsubj)), 0.5) - 1
     min_vals, max_vals = group_analysis_signs(design, contrast, mask, signs)
     return min_vals, max_vals
@@ -500,7 +498,7 @@ def run_run_models(subject_nos=SUBJECTS, run_nos = RUNS):
         for run in run_nos:
             try:
                 run_model(subj, run)
-            except IOError:
+            except OSError:
                 print('Skipping subject %d, run %d' % (subj, run))
 
 
@@ -510,7 +508,7 @@ def run_fixed_models(subject_nos=SUBJECTS, designs=DESIGNS):
         for design in designs:
             try:
                 fixed_effects(subj, design)
-            except IOError:
+            except OSError:
                 print('Skipping subject %d, design %s' % (subj, design))
 
 
