@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function # Python 2/3 compatibility
 __doc__ = """
 Full step-by-step example of fitting a GLM to experimental data and visualizing
 the results.
@@ -22,7 +21,7 @@ Author : Bertrand Thirion, 2010--2012
 """
 print(__doc__)
 
-from os import mkdir, getcwd, path
+from os import getcwd, mkdir, path
 
 import numpy as np
 
@@ -31,16 +30,14 @@ try:
 except ImportError:
     raise RuntimeError("This script needs the matplotlib library")
 
-from nibabel import save
-
-from nipy.modalities.fmri.glm import FMRILinearModel
-from nipy.modalities.fmri.design_matrix import make_dmtx
-from nipy.modalities.fmri.experimental_paradigm import \
-    load_paradigm_from_csv_file
-from nipy.labs.viz import plot_map, cm
-
 # Local import
 from get_data_light import DATA_DIR, get_first_level_dataset
+from nibabel import save
+
+from nipy.labs.viz import cm, plot_map
+from nipy.modalities.fmri.design_matrix import make_dmtx
+from nipy.modalities.fmri.experimental_paradigm import load_paradigm_from_csv_file
+from nipy.modalities.fmri.glm import FMRILinearModel
 
 #######################################
 # Data and analysis parameters
@@ -69,7 +66,7 @@ write_dir = path.join(getcwd(), 'results')
 if not path.exists(write_dir):
     mkdir(write_dir)
 
-print('Computation will be performed in directory: %s' % write_dir)
+print(f'Computation will be performed in directory: {write_dir}')
 
 ########################################
 # Design matrix
@@ -96,7 +93,7 @@ plt.savefig(path.join(write_dir, 'design_matrix.png'))
 contrasts = {}
 n_columns = len(design_matrix.names)
 for i in range(paradigm.n_conditions):
-    contrasts['%s' % design_matrix.names[2 * i]] = np.eye(n_columns)[2 * i]
+    contrasts[f'{design_matrix.names[2 * i]}'] = np.eye(n_columns)[2 * i]
 
 # and more complex/ interesting ones
 contrasts["audio"] = contrasts["clicDaudio"] + contrasts["clicGaudio"] +\
@@ -137,15 +134,15 @@ for index, (contrast_id, contrast_val) in enumerate(contrasts.items()):
     print('  Contrast % 2i out of %i: %s' %
           (index + 1, len(contrasts), contrast_id))
     # save the z_image
-    image_path = path.join(write_dir, '%s_z_map.nii' % contrast_id)
+    image_path = path.join(write_dir, f'{contrast_id}_z_map.nii')
     z_map, = fmri_glm.contrast(contrast_val, con_id=contrast_id, output_z=True)
     save(z_map, image_path)
 
     # Create snapshots of the contrasts
-    vmax = max(- z_map.get_data().min(), z_map.get_data().max())
+    vmax = max(- z_map.get_fdata().min(), z_map.get_fdata().max())
     if index > 0:
         plt.clf()
-    plot_map(z_map.get_data(), z_map.get_affine(),
+    plot_map(z_map.get_fdata(), z_map.affine,
              cmap=cm.cold_hot,
              vmin=- vmax,
              vmax=vmax,
@@ -155,8 +152,8 @@ for index, (contrast_id, contrast_val) in enumerate(contrasts.items()):
              black_bg=True,  # looks much better thus
              figure=10,
              threshold=2.5)
-    plt.savefig(path.join(write_dir, '%s_z_map.png' % contrast_id))
+    plt.savefig(path.join(write_dir, f'{contrast_id}_z_map.png'))
 
-print("All the  results were witten in %s" % write_dir)
+print(f"All the  results were witten in {write_dir}")
 
 plt.show()
