@@ -7,13 +7,10 @@ of the mixture distribution using an EM algorithm.
 
 Author: Bertrand Thirion and Merlin Keller 2005-2008
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
-import scipy.stats as st
 import scipy.special as sp
-
+import scipy.stats as st
 
 #############################################################################
 # Auxiliary functions #######################################################
@@ -118,7 +115,7 @@ def _gam_param(x, z):
 ##############################################################################
 
 
-class Gamma(object):
+class Gamma:
     """ Basic one dimensional Gaussian-Gamma Mixture estimation class
 
     Note that it can work with positive or negative values,
@@ -162,7 +159,7 @@ class Gamma(object):
 ##############################################################################
 
 
-class GGM(object):
+class GGM:
     """
     This is the basic one dimensional Gaussian-Gamma Mixture estimation class
     Note that it can work with positive or negative values,
@@ -185,7 +182,7 @@ class GGM(object):
         self.mixt = mixt
 
     def parameters(self):
-        """ print the paramteres of self
+        """ print the parameters of self
         """
         print("Gaussian: mean: ", self.mean, "variance: ", self.var)
         print("Gamma: shape: ", self.shape, "scale: ", self.scale)
@@ -290,7 +287,7 @@ class GGM(object):
         step = 3.5 * np.std(x) / np.exp(np.log(np.size(x)) / 3)
         bins = max(10, int((x.max() - x.min()) / step))
         h, c = np.histogram(x, bins)
-        h = h.astype(np.float) / np.size(x)
+        h = h.astype(np.float64) / np.size(x)
         p = self.mixt
 
         dc = c[1] - c[0]
@@ -298,14 +295,14 @@ class GGM(object):
         z = np.zeros(np.size(c))
         z = _gam_dens(self.shape, self.scale, c) * p * dc
 
-        import matplotlib.pylab as mp
-        mp.figure()
-        mp.plot(0.5 * (c[1:] + c[:-1]), h)
-        mp.plot(c, y, 'r')
-        mp.plot(c, z, 'g')
-        mp.plot(c, z + y, 'k')
-        mp.title('Fit of the density with a Gamma-Gaussians mixture')
-        mp.legend(('data', 'gaussian acomponent', 'gamma component',
+        import matplotlib.pyplot as plt
+        plt.figure()
+        plt.plot(0.5 * (c[1:] + c[:-1]), h)
+        plt.plot(c, y, 'r')
+        plt.plot(c, z, 'g')
+        plt.plot(c, z + y, 'k')
+        plt.title('Fit of the density with a Gamma-Gaussians mixture')
+        plt.legend(('data', 'gaussian acomponent', 'gamma component',
                    'mixture distribution'))
 
     def posterior(self, x):
@@ -332,7 +329,7 @@ class GGM(object):
 ##############################################################################
 
 
-class GGGM(object):
+class GGGM:
     """
     The basic one dimensional Gamma-Gaussian-Gamma Mixture estimation
     class, where the first gamma has a negative sign, while the second
@@ -381,14 +378,14 @@ class GGGM(object):
         print("Negative Gamma: shape: ", self.shape_n,
               "scale: ", self.scale_n)
         print("Gaussian: mean: ", self.mean, "variance: ", self.var)
-        print("Poitive Gamma: shape: ", self.shape_p, "scale: ", self.scale_p)
+        print("Positive Gamma: shape: ", self.shape_p, "scale: ", self.scale_p)
         mixt = self.mixt
         print("Mixture neg. gamma: ", mixt[0], "Gaussian: ", mixt[1],
               "pos. gamma: ", mixt[2])
 
     def init(self, x, mixt=None):
         """
-        initialization of the differnt parameters
+        initialization of the different parameters
 
         Parameters
         ----------
@@ -432,7 +429,7 @@ class GGGM(object):
 
     def init_fdr(self, x, dof=-1, copy=True):
         """
-        Initilization of the class based on a fdr heuristic: the
+        Initialization of the class based on a fdr heuristic: the
         probability to be in the positive component is proportional to
         the 'positive fdr' of the data.  The same holds for the
         negative part.  The point is that the gamma parts should model
@@ -440,11 +437,11 @@ class GGGM(object):
 
         Parameters
         ----------
-        x: array of shape(nbitem)
+        x: array of shape (nbitem)
             the data under consideration
         dof: integer, optional
-            number of degrees of freedom if x is thought to be a student
-            variate. By default, it is handeled as a normal
+            number of degrees of freedom if x is thought to be a Student
+            variate. By default, it is handled as a normal
         copy: boolean, optional
             If True, copy the data.
         """
@@ -641,12 +638,12 @@ class GGGM(object):
         mpaxes: matplotlib axes, optional
             axes handle used for the plot if None, new axes are created.
         """
-        import matplotlib.pylab as mp
+        import matplotlib.pyplot as plt
 
         step = 3.5 * np.std(x) / np.exp(np.log(np.size(x)) / 3)
         bins = max(10, int((x.max() - x.min()) / step))
         h, c = np.histogram(x, bins)
-        h = h.astype(np.float) / np.size(x)
+        h = h.astype(np.float64) / np.size(x)
         dc = c[1] - c[0]
 
         ng = self.mixt[0] * _gam_dens(self.shape_n, self.scale_n, - c)
@@ -655,8 +652,8 @@ class GGGM(object):
         z = y + pg + ng
 
         if mpaxes is None:
-            mp.figure()
-            ax = mp.subplot(1, 1, 1)
+            plt.figure()
+            ax = plt.subplot(1, 1, 1)
         else:
             ax = mpaxes
 
