@@ -51,7 +51,7 @@ class WeightedForest(Forest):
     parents: array of shape (self.V) the parent array
     edges: array of shape (self.E,2) reprensenting pairwise neighbors
     weights, array of shape (self.E), +1/-1 for scending/descending links
-    children: list of arrays that represents the childs of any node
+    children: list of arrays that represents the children of any node
     height: array of shape(self.V)
     """
 
@@ -221,10 +221,8 @@ class WeightedForest(Forest):
         way such that parent[i]>i for all i
         Only the leaves are listeed, not the subtrees themselves
         """
-        lst = []
+        lst = [np.array([], np.int_) for i in range(self.V)]
         n = np.sum(self.isleaf())
-        for i in range(self.V):
-            lst.append(np.array([], np.int_))
         for i in range(n):
             lst[i] = np.array([i], np.int_)
         for i in range(self.V - 1):
@@ -630,8 +628,8 @@ def ward_quick(G, feature, verbose=False):
 
     Caveat : only approximate
     """
-    warn('Function ward_quick from ' +
-         'nipy.algorithms.clustering.hierrachical_clustering ' +
+    warn('Function ward_quick from '
+         'nipy.algorithms.clustering.hierrachical_clustering '
          'deprecated, will be removed',
          FutureWarning,
          stacklevel=2)
@@ -904,8 +902,8 @@ def ward(G, feature, verbose=False):
     When G has more than 1 connected component, t is no longer a tree.  This
     case is handled cleanly now
     """
-    warn('Function ward from ' +
-         'nipy.algorithms.clustering.hierrachical_clustering ' +
+    warn('Function ward from '
+         'nipy.algorithms.clustering.hierrachical_clustering '
          'deprecated, will be removed',
          FutureWarning,
          stacklevel=2)
