@@ -2,7 +2,6 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 #from _clustering import *
 #from _clustering import __doc__
-from __future__ import print_function, absolute_import
 
 import numpy as np
 
@@ -17,13 +16,13 @@ def kmeans(X, nbclusters=2, Labels=None, maxiter=300, delta=0.0001, verbose=0,
        data array
     nbclusters (int), the number of desired clusters
     Labels = None array of shape (n) prior Labels.
-           if None or inadequate a random initilization is performed.
+           if None or inadequate a random initialization is performed.
     maxiter=300 (int), the maximum number of iterations  before convergence
     delta: float, optional,
            the relative increment in the results
            before declaring convergence.
-    verbose: verbosity mode, optionall
-    ninit: int, optional, number of random initalizations
+    verbose: verbosity mode, optional
+    ninit: int, optional, number of random initializations
 
     Returns
     -------
@@ -63,7 +62,7 @@ def kmeans(X, nbclusters=2, Labels=None, maxiter=300, delta=0.0001, verbose=0,
 
     if Labels is not None:
         if np.size(Labels) == nbitems:
-            Labels = Labels.astype(np.int)
+            Labels = Labels.astype(np.int_)
             OK = (Labels.min() > -1) & (Labels.max() < nbclusters + 1)
             if OK:
                 maxiter = int(maxiter)
@@ -128,7 +127,7 @@ def _EStep(x, centers):
     z vector of shape(n), the resulting assignment
     """
     nbitem = x.shape[0]
-    z = - np.ones(nbitem).astype(np.int)
+    z = - np.ones(nbitem).astype(np.int_)
     mindist = np.inf * np.ones(nbitem)
     k = centers.shape[0]
     for q in range(k):
@@ -172,7 +171,7 @@ def _kmeans(X, nbclusters=2, Labels=None, maxiter=300, delta=1.e-4,
        data array
     nbclusters (int), the number of desired clusters
     Labels: array of shape (n) prior Labels, optional
-            if None or inadequate a random initilization is performed.
+            if None or inadequate a random initialization is performed.
     maxiter: int, optional
              the maximum number of iterations  before convergence
     delta: float, optional
