@@ -9,8 +9,8 @@ from warnings import warn
 
 import numpy as np
 
-warn('Module nipy.algorithms.clustering.von_mises_fisher_mixture' +
-     'deprecated, will be removed',
+warn('Module nipy.algorithms.clustering.von_mises_fisher_mixture deprecated, '
+     'will be removed',
      FutureWarning,
      stacklevel=2)
 
@@ -60,7 +60,7 @@ class VonMisesMixture:
 
         Returns
         -------
-        like: array of shape(n, self.k), with non-neagtive values
+        like: array of shape(n, self.k), with non-negative values
               the density
         """
         n = x.shape[0]
@@ -84,7 +84,7 @@ class VonMisesMixture:
 
         Returns
         -------
-        like: array of shape(n, self.k), with non-neagtive values
+        like: array of shape(n, self.k), with non-negative values
               the density
         """
         return np.exp(self.log_density_per_component(x))
