@@ -2,38 +2,28 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """ Testing diagnostic screen
 """
-from __future__ import absolute_import
 
 import os
 from os.path import join as pjoin
-
 from warnings import catch_warnings, simplefilter
 
 import numpy as np
+import pytest
+from numpy.testing import (
+    assert_almost_equal,
+    assert_array_equal,
+)
 
 import nipy as ni
 from nipy.core.api import rollimg
-from ..screens import screen, write_screen_res
-from ..timediff import time_slice_diffs
-from ...utils.pca import pca
-from ...utils.tests.test_pca import res2pos1
-
-from nibabel.tmpdirs import InTemporaryDirectory
-
-from nose.tools import (assert_true, assert_false, assert_equal, assert_raises)
-
-from numpy.testing import (assert_array_equal, assert_array_almost_equal,
-                           assert_almost_equal)
-
-try:
-    from numpy.testing import decorators
-except ImportError:
-    from numpy.testing import dec
-    decorators = dec
-
 from nipy.testing import funcfile
 from nipy.testing.decorators import needs_mpl_agg
 
+from ...utils.pca import pca
+from ...utils.tests.test_pca import res2pos1
+from ..screens import screen, write_screen_res
+from ..timediff import time_slice_diffs
+
 
 def _check_pca(res, pca_res):
     # Standardize output vector signs
@@ -55,18 +45,18 @@ def test_screen():
     # slice axis below
     img = img.renamed_axes(k='slice')
     res = screen(img)
-    assert_equal(res['mean'].ndim, 3)
-    assert_equal(res['pca'].ndim, 4)
-    assert_equal(sorted(res.keys()),
+    assert res['mean'].ndim == 3
+    assert res['pca'].ndim == 4
+    assert (sorted(res.keys()) ==
                  ['max', 'mean', 'min',
                   'pca', 'pca_res',
                   'std', 'ts_res'])
-    data = img.get_data()
+    data = img.get_fdata()
     # Check summary images
-    assert_array_equal(np.max(data, axis=-1), res['max'].get_data())
-    assert_array_equal(np.mean(data, axis=-1), res['mean'].get_data())
-    assert_array_equal(np.min(data, axis=-1), res['min'].get_data())
-    assert_array_equal(np.std(data, axis=-1), res['std'].get_data())
+    assert_array_equal(np.max(data, axis=-1), res['max'].get_fdata())
+    assert_array_equal(np.mean(data, axis=-1), res['mean'].get_fdata())
+    assert_array_equal(np.min(data, axis=-1), res['min'].get_fdata())
+    assert_array_equal(np.std(data, axis=-1), res['std'].get_fdata())
     pca_res = pca(data, axis=-1, standardize=False, ncomp=10)
     # On windows, there seems to be some randomness in the PCA output vector
     # signs; this routine sets the basis vectors to have first value positive,
@@ -77,11 +67,11 @@ def test_screen():
     # Test that screens accepts and uses time axis
     data_mean = data.mean(axis=-1)
     res = screen(img, time_axis='t')
-    assert_array_equal(data_mean, res['mean'].get_data())
+    assert_array_equal(data_mean, res['mean'].get_fdata())
     _check_pca(res, pca_res)
     _check_ts(res, data, 3, 2)
     res = screen(img, time_axis=-1)
-    assert_array_equal(data_mean, res['mean'].get_data())
+    assert_array_equal(data_mean, res['mean'].get_fdata())
     _check_pca(res, pca_res)
     _check_ts(res, data, 3, 2)
     t0_img = rollimg(img, 't')
@@ -89,11 +79,11 @@ def test_screen():
     res = screen(t0_img, time_axis='t')
     t0_pca_res = pca(t0_data, axis=0, standardize=False, ncomp=10)
     t0_pca_res = res2pos1(t0_pca_res)
-    assert_array_equal(data_mean, res['mean'].get_data())
+    assert_array_equal(data_mean, res['mean'].get_fdata())
     _check_pca(res, t0_pca_res)
     _check_ts(res, t0_data, 0, 3)
     res = screen(t0_img, time_axis=0)
-    assert_array_equal(data_mean, res['mean'].get_data())
+    assert_array_equal(data_mean, res['mean'].get_fdata())
     _check_pca(res, t0_pca_res)
     _check_ts(res, t0_data, 0, 3)
     # Check screens uses slice axis
@@ -105,12 +95,12 @@ def test_screen():
     # First re-show that when we don't specify, we get the default
     res = screen(img)
     _check_ts(res, data, 3, 2)
-    assert_raises(AssertionError, _check_ts, res, data, 3, 0)
+    pytest.raises(AssertionError, _check_ts, res, data, 3, 0)
     # Then specify, get non-default
     slicey_img = img.renamed_axes(slice='k', i='slice')
     res = screen(slicey_img)
     _check_ts(res, data, 3, 0)
-    assert_raises(AssertionError, _check_ts, res, data, 3, 2)
+    pytest.raises(AssertionError, _check_ts, res, data, 3, 2)
 
 
 def pca_pos(data4d):
@@ -129,16 +119,16 @@ def test_screen_slice_axis():
     exp_res = screen(img, slice_axis='k')
     with catch_warnings():
         simplefilter('error')
-        assert_raises(FutureWarning, screen, img)
-        assert_raises(FutureWarning, screen, img, slice_axis=None)
+        pytest.raises(FutureWarning, screen, img)
+        pytest.raises(FutureWarning, screen, img, slice_axis=None)
         explicit_img = img.renamed_axes(k='slice')
         # Now the analysis works without warning
         res = screen(explicit_img)
         # And is the expected analysis
         # Very oddly on scipy 0.9 32 bit - at least - results differ between
         # runs, so we need assert_almost_equal
-        assert_almost_equal(pca_pos(res['pca'].get_data()),
-                            pca_pos(exp_res['pca'].get_data()))
+        assert_almost_equal(pca_pos(res['pca'].get_fdata()),
+                            pca_pos(exp_res['pca'].get_fdata()))
         assert_array_equal(res['ts_res']['slice_mean_diff2'],
                            exp_res['ts_res']['slice_mean_diff2'])
         # Turn off warnings, also get expected analysis
@@ -149,26 +139,25 @@ def test_screen_slice_axis():
 
 
 @needs_mpl_agg
-def test_write_screen_res():
+def test_write_screen_res(in_tmp_path):
     img = ni.load_image(funcfile)
-    with InTemporaryDirectory():
-        res = screen(img)
-        os.mkdir('myresults')
-        write_screen_res(res, 'myresults', 'myana')
-        pca_img = ni.load_image(pjoin('myresults', 'pca_myana.nii'))
-        assert_equal(pca_img.shape, img.shape[:-1] + (10,))
-        # Make sure we get the same output image even from rolled image
-        # Do fancy roll to put time axis first, and slice axis last. This does
-        # a stress test on the axis ordering, but also makes sure that we are
-        # getting the number of components from the right place.  If we were
-        # getting the number of components from the length of the last axis,
-        # instead of the length of the 't' axis in the returned pca image, this
-        # would be wrong (=21) which would also be more than the number of
-        # basis vectors (19) so raise an error
-        rimg = img.reordered_axes([3, 2, 0, 1])
-        os.mkdir('rmyresults')
-        rres = screen(rimg)
-        write_screen_res(rres, 'rmyresults', 'myana')
-        rpca_img = ni.load_image(pjoin('rmyresults', 'pca_myana.nii'))
-        assert_equal(rpca_img.shape, img.shape[:-1] + (10,))
-        del pca_img, rpca_img
+    res = screen(img)
+    os.mkdir('myresults')
+    write_screen_res(res, 'myresults', 'myana')
+    pca_img = ni.load_image(pjoin('myresults', 'pca_myana.nii'))
+    assert pca_img.shape == img.shape[:-1] + (10,)
+    # Make sure we get the same output image even from rolled image
+    # Do fancy roll to put time axis first, and slice axis last. This does
+    # a stress test on the axis ordering, but also makes sure that we are
+    # getting the number of components from the right place.  If we were
+    # getting the number of components from the length of the last axis,
+    # instead of the length of the 't' axis in the returned pca image, this
+    # would be wrong (=21) which would also be more than the number of
+    # basis vectors (19) so raise an error
+    rimg = img.reordered_axes([3, 2, 0, 1])
+    os.mkdir('rmyresults')
+    rres = screen(rimg)
+    write_screen_res(rres, 'rmyresults', 'myana')
+    rpca_img = ni.load_image(pjoin('rmyresults', 'pca_myana.nii'))
+    assert rpca_img.shape == img.shape[:-1] + (10,)
+    del pca_img, rpca_img
