@@ -9,13 +9,12 @@ labeled [1..V] and [1..W] respectively.
 
 Author: Bertrand Thirion, 2006--2011
 """
-from __future__ import absolute_import
 
 import numpy as np
 
 
 def check_feature_matrices(X, Y):
-    """ checks wether the dismension of X and Y are consistent
+    """ checks whether the dimensions of X and Y are consistent
 
     Parameters
     ----------
@@ -99,7 +98,7 @@ def cross_eps(X, Y, eps=1.):
         idx = np.asanyarray(np.where(dist < eps))
         data = np.hstack((data, dist[idx.ravel()]))
         ij = np.vstack((ij, np.hstack((
-                        i * np.ones((idx.size, 1)), idx.T)))).astype(np.int)
+                        i * np.ones((idx.size, 1)), idx.T)))).astype(np.int_)
 
     data = np.maximum(data, 1.e-15)
     adj = coo_matrix((data, ij.T), shape=(X.shape[0], Y.shape[0]))
@@ -150,7 +149,7 @@ def cross_knn(X, Y, k=1):
     return bipartite_graph_from_coo_matrix(adj)
 
 
-class BipartiteGraph(object):
+class BipartiteGraph:
     """ Bipartite graph class
 
     A graph for which there are two types of nodes, such that
@@ -173,7 +172,7 @@ class BipartiteGraph(object):
         edges=None: array of shape (self.E, 2)
                     the edge array of the graph
         weights=None: array of shape (self.E)
-                      the asociated weights array
+                      the associated weights array
         """
         V = int(V)
         W = int(W)
@@ -183,13 +182,13 @@ class BipartiteGraph(object):
         self.W = W
         self.E = 0
         if (edges is None) & (weights is None):
-            self.edges = np.array([], np.int)
+            self.edges = np.array([], np.int_)
             self.weights = np.array([])
         else:
             if edges.shape[0] == np.size(weights):
                 E = edges.shape[0]
                 self.E = E
-                self.edges = - np.ones((E, 2), np.int)
+                self.edges = - np.ones((E, 2), np.int_)
                 self.set_edges(edges)
                 self.set_weights(weights)
             else:
