@@ -2,30 +2,16 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """ Image interpolators using ndimage.
 """
-from __future__ import absolute_import
 
 import tempfile
 
-from distutils.version import LooseVersion as LV
-
 import numpy as np
+from scipy.ndimage import map_coordinates, spline_filter
 
-import scipy
-from scipy import ndimage
-
-from ..fixes.scipy.ndimage import map_coordinates
 from ..utils import seq_prod
 
 
-# Earlier versions of Scipy don't have mode for spline_filter
-SCIPY_VERSION = LV(scipy.__version__)
-SPLINE_FILTER_HAS_MODE = SCIPY_VERSION >= LV('1.2')
-# Fixes in interpolation in scipy >= 1.6 force pre-padding
-# in knot calculations.
-SPLINE_FILTER_NEEDS_PAD = SCIPY_VERSION >= LV('1.6')
-
-
-class ImageInterpolator(object):
+class ImageInterpolator:
     """ Interpolate Image instance at arbitrary points in world space
 
     The resampling is done with ``scipy.ndimage``.
@@ -33,7 +19,7 @@ class ImageInterpolator(object):
 
     # Padding for prefilter calculation in 'nearest' and 'grid-constant' mode.
     # See: https://github.com/scipy/scipy/issues/13600
-    n_prepad_if_needed = 12 if SPLINE_FILTER_NEEDS_PAD else 0
+    n_prepad_if_needed = 12
 
     def __init__(self, image, order=3, mode='constant', cval=0.0):
         """
@@ -75,17 +61,16 @@ class ImageInterpolator(object):
         return self._order
 
     def _buildknots(self):
-        data = np.nan_to_num(self.image.get_data()).astype(np.float64)
+        data = np.nan_to_num(self.image.get_fdata()).astype(np.float64)
         if self.order > 1:
             if self.mode in ('nearest', 'grid-constant'):
                 # See: https://github.com/scipy/scipy/issues/13600
                 self._n_prepad = self.n_prepad_if_needed
                 if self._n_prepad != 0:
                     data = np.pad(data, self._n_prepad, mode='edge')
-            kwargs = dict(order=self.order)
-            if SPLINE_FILTER_HAS_MODE:
-                kwargs['mode'] = self.mode
-            data = ndimage.spline_filter(data, **kwargs)
+            kwargs = {'order': self.order}
+            kwargs['mode'] = self.mode
+            data = spline_filter(data, **kwargs)
         self._datafile = tempfile.TemporaryFile()
         data.tofile(self._datafile)
         self._data = np.memmap(self._datafile,
