@@ -1,15 +1,13 @@
-from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 
 import numpy as np
+from numpy.testing import assert_array_almost_equal
 
 from .... import load_image
 from ....testing import anatfile
 from ..histogram_registration import HistogramRegistration
 
-from numpy.testing import assert_array_almost_equal
-
 anat_img = load_image(anatfile)
 
 def test_registers():
@@ -30,4 +28,4 @@ def test_registers():
                                   interp=interp)
         R.subsample([2,2,2])
         affine = R.optimize(affine_type)
-        yield assert_array_almost_equal, affine.as_affine(), np.eye(4), 2
+        assert_array_almost_equal(affine.as_affine(), np.eye(4), 2)
