@@ -123,14 +123,14 @@ from sympy.utilities.lambdify import implemented_function, lambdify
 from nipy.algorithms.utils.matrices import full_rank, matrix_rank
 
 # Legacy repr printing from numpy.
-from nipy.utils import VisibleDeprecationWarning, _NoValue
+from nipy.utils import VisibleDeprecationWarning, _NoValue, deprecate_with_doc
 
 
 def _to_str(s):
     return s.decode('latin1') if isinstance(s, bytes) else str(s)
 
 
-@np.deprecate(message = "Please use sympy.Dummy instead of this function")
+@deprecate_with_doc("please use sympy.Dummy instead")
 def make_dummy(name):
     """ Make dummy variable of given name
 
@@ -302,11 +302,10 @@ def getparams(expression):
         expression = expression.reshape((np.prod(expression.shape),))
     for term in expression:
         atoms = atoms.union(sympy.sympify(term).atoms())
-    params = []
-    for atom in atoms:
-        if isinstance(atom, sympy.Symbol) and not is_term(atom):
-            params.append(atom)
-    params.sort(key=default_sort_key)
+    params = sorted((atom
+                     for atom in atoms
+                     if isinstance(atom, sympy.Symbol) and not is_term(atom)),
+                    key=default_sort_key)
     return params
 
 
@@ -330,11 +329,8 @@ def getterms(expression):
         expression = expression.reshape((np.prod(expression.shape),))
     for e in expression:
         atoms = atoms.union(e.atoms())
-    terms = []
-    for atom in atoms:
-        if is_term(atom):
-            terms.append(atom)
-    terms.sort(key=default_sort_key)
+    terms = sorted((atom for atom in atoms if is_term(atom)),
+                   key=default_sort_key)
     return terms
 
 
@@ -1061,7 +1057,7 @@ class Factor(Formula):
         """
         if level not in self.levels:
             raise ValueError('level not found')
-        return self[f"{self.name}_{str(level)}"]
+        return self[f"{self.name}_{level}"]
 
     def _getmaineffect(self, ref=-1):
         v = list(self._terms.copy())
