@@ -3,15 +3,9 @@
 """ models - Statistical Models
 """
 
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext'
 
+
+from . import glm, model, regression
 from .info import __doc__
-
-from . import model
-from . import regression
-from . import glm
-
-from nipy.testing import Tester
-test = Tester().test
