@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import numpy as np
@@ -6,7 +5,8 @@ import numpy as np
 from . import links as L
 from . import varfuncs as V
 
-class Family(object):
+
+class Family:
 
     """
     A class to model one-parameter exponential
@@ -29,7 +29,7 @@ class Family(object):
         if hasattr(self, "links"):
             if link not in self.links:
                 raise ValueError(
-                    'invalid link for family, should be in %s' % self.links)
+                    f'invalid link for family, should be in {self.links}')
 
     def _getlink(self):
         return self._link
@@ -71,7 +71,7 @@ class Family(object):
            scale -- optional scale in denominator of deviance
 
         OUTPUTS: dev
-           dev   -- DEV, as described aboce
+           dev   -- DEV, as described above
 
         """
 
