@@ -1,7 +1,8 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+from functools import cached_property
+
 import numpy as np
-from nibabel.onetime import auto_attr
 from numpy.linalg import inv
 from scipy.stats import t as t_distribution
 
@@ -118,14 +119,14 @@ class LikelihoodModelResults:
         # put this as a parameter of LikelihoodModel
         self.df_resid = self.df_total - self.df_model
 
-    @auto_attr
+    @cached_property
     def logL(self):
         """
         The maximized log-likelihood
         """
         return self.model.logL(self.theta, self.Y, nuisance=self.nuisance)
 
-    @auto_attr
+    @cached_property
     def AIC(self):
         """
         Akaike Information Criterion
@@ -133,7 +134,7 @@ class LikelihoodModelResults:
         p = self.theta.shape[0]
         return -2 * self.logL + 2 * p
 
-    @auto_attr
+    @cached_property
     def BIC(self):
         """
         Schwarz's Bayesian Information Criterion
@@ -189,7 +190,7 @@ class LikelihoodModelResults:
         or a matrix.
         """
         if self.cov is None:
-            raise ValueError('need covariance of parameters for computing' +\
+            raise ValueError('need covariance of parameters for computing '
                              '(unnormalized) covariances')
 
         if dispersion is None:
