@@ -1,8 +1,6 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 ''' General matrix and other utilities for statistics '''
-from __future__ import print_function
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext'
 
@@ -17,13 +15,13 @@ def mad(a, c=0.6745, axis=0):
     median(abs(a - median(a))) / c
     """
     _shape = a.shape
-    a.shape = np.product(a.shape, axis=0)
+    a.shape = np.prod(a.shape, axis=0)
     m = np.median(np.fabs(a - np.median(a))) / c
     a.shape = _shape
     return m
 
 
-class StepFunction(object):
+class StepFunction:
     """ A basic step function
 
     Values at the ends are handled in the simplest way possible: everything to
@@ -75,7 +73,7 @@ def ECDF(values):
     """
     x = np.array(values, copy=True)
     x.sort()
-    x.shape = np.product(x.shape, axis=0)
+    x.shape = np.prod(x.shape, axis=0)
     n = x.shape[0]
     y = (np.arange(n) + 1.) / n
     return StepFunction(x, y)
