@@ -3,7 +3,6 @@
 """
 Utilities for one sample t-tests
 """
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext'
 
@@ -11,6 +10,7 @@ import numpy as np
 
 from ..utils.matrices import pos_recipr
 
+
 def estimate_mean(Y, sd):
     """ Estimate the mean of a sample given information about
     the standard deviations of each entry.
@@ -76,7 +76,7 @@ def estimate_varatio(Y, sd, df=None, niter=10):
         Data for which mean is to be estimated.
         Should have shape[0] == number of subjects.
     sd : array
-        Standard deviation (subject specific) 
+        Standard deviation (subject specific)
         of the data for which the mean is to be estimated.
         Should have shape[0] == number of subjects.
     df : int or None, optional
@@ -127,7 +127,7 @@ def estimate_varatio(Y, sd, df=None, niter=10):
         df = np.ones(nsubject)
     df.shape = (1, nsubject)
     _Sshape = S.shape
-    S.shape = (S.shape[0], np.product(S.shape[1:]))
+    S.shape = (S.shape[0], np.prod(S.shape[1:]))
 
     value = {}
     value['fixed'] = (np.dot(df, S) / df.sum()).reshape(_Sshape[1:])
