@@ -5,7 +5,6 @@ this module contains a function to perform fast distance computation on arrays
 
 Author : Bertrand Thirion, 2008-2011
 """
-from __future__ import absolute_import
 import numpy as np
 
 
@@ -22,7 +21,7 @@ def euclidean_distance(X, Y=None):
 
     Returns
     -------
-    ED, array fo shape(n1, n2) with all the pairwise distance
+    ED, array of shape(n1, n2) with all the pairwise distance
     """
     if Y is None:
         Y = X
