@@ -183,12 +183,12 @@ class ArrayCoordMap:
         are 'array' coordinates.
 
         """
-        slices = tuple([slice(0,s,1) for s in shape])
+        slices = tuple(slice(0,s,1) for s in shape)
         return Grid(coordmap)[slices]
 
     def __repr__(self):
         return "ArrayCoordMap(\n  coordmap=" + \
-            '\n  '.join(repr(self.coordmap).split('\n')) + f',\n  shape={repr(self.shape)}' + '\n)'
+            '\n  '.join(repr(self.coordmap).split('\n')) + f',\n  shape={self.shape!r}' + '\n)'
 
 
 def _slice(coordmap, shape, *slices):
