@@ -145,7 +145,7 @@ class CoordinateMap:
     _doc['function_range'] = 'The range of the function, a CoordinateSystem.'
 
     inverse_function = np.log
-    _doc['inverse_function'] = 'The inverse function from function_range' + \
+    _doc['inverse_function'] = 'The inverse function from function_range ' \
                                'to function_domain, if supplied.'
 
     ndims = (1,1)
@@ -200,9 +200,9 @@ class CoordinateMap:
 
     def __setattr__(self, key, value):
         if key in self.__dict__:
-            raise AttributeError('the value of %s has already been '
+            raise AttributeError(f'the value of {key} has already been '
                                  'set and all attributes are '
-                                 'read-only' % key)
+                                 'read-only')
         object.__setattr__(self, key, value)
 
     ###################################################################
@@ -423,9 +423,9 @@ class CoordinateMap:
 
     def __repr__(self):
         if self.inverse_function is None:
-            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={repr(self.function)}\n  )"
+            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={self.function!r}\n  )"
         else:
-            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={repr(self.function)},\n   inverse_function={repr(self.inverse_function)}\n  )"
+            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={self.function!r},\n   inverse_function={self.inverse_function!r}\n  )"
 
 
     def _checkfunction(self):
@@ -502,15 +502,15 @@ class AffineTransform:
 
     _doc = {}
     affine = np.diag([3,4,5,1])
-    _doc['affine'] = 'The matrix representing an affine transformation ' + \
+    _doc['affine'] = 'The matrix representing an affine transformation ' \
                        'homogeneous form.'
 
     function_domain = CoordinateSystem('x')
-    _doc['function_domain'] = 'The domain of the affine transformation, ' + \
+    _doc['function_domain'] = 'The domain of the affine transformation, ' \
                               'a CoordinateSystem.'
 
     function_range = CoordinateSystem('y')
-    _doc['function_range'] = 'The range of the affine transformation, ' + \
+    _doc['function_range'] = 'The range of the affine transformation, ' \
                              'a CoordinateSystem.'
 
     ndims = (3,3)
@@ -558,10 +558,10 @@ class AffineTransform:
                              'affine matrix shape')
         # Test that it is actually an affine mapping in homogeneous
         # form
-        bottom_row = np.array([0]*self.ndims[0] + [1])
-        if not np.all(affine[-1] == bottom_row):
-            raise ValueError('the homogeneous transform should have bottom=' + \
-                             f'row {repr(bottom_row)}')
+        bottom_row = np.array([0] * self.ndims[0] + [1])
+        if not np.allclose(affine[-1].astype(float), bottom_row):
+            raise ValueError('the homogeneous transform should have bottom='
+                             f'row {bottom_row!r}')
         self.affine = affine
 
     ###################################################################
@@ -1113,7 +1113,7 @@ def product(*cmaps, **kwargs):
     if allaffine:
         return _product_affines(*cmaps, **kwargs)
     else:
-        warnings.warn("product of non-affine CoordinateMaps is less robust than"+
+        warnings.warn("product of non-affine CoordinateMaps is less robust than "
                       "the AffineTransform")
         return _product_cmaps(*[_as_coordinate_map(cmap) for cmap in cmaps],
                               **kwargs)
@@ -1370,7 +1370,7 @@ def renamed_domain(mapping, newnames, name=''):
 
     for key in list(newnames):
         if key not in mapping.function_domain.coord_names:
-            raise ValueError(f'no domain coordinate named {str(key)}')
+            raise ValueError(f'no domain coordinate named {key}')
 
     new_coord_names = []
     for n in mapping.function_domain.coord_names:
@@ -1434,7 +1434,7 @@ def renamed_range(mapping, newnames):
 
     for key in list(newnames):
         if key not in mapping.function_range.coord_names:
-            raise ValueError(f'no range coordinate named {str(key)}')
+            raise ValueError(f'no range coordinate named {key}')
 
     new_coord_names = []
     for n in mapping.function_range.coord_names:
@@ -2019,14 +2019,13 @@ def input_axis_index(coordmap, axis_id, fix0=True):
             return in_no
         out2in = axmap(coordmap, 'out2in', fix0=fix0)
         if not out2in[axis_id] == in_no:
-            raise AxisError('Name "%s" present in input and output but '
-                            'they do not appear to match' % axis_id)
+            raise AxisError(f'Name "{axis_id}" present in input and output but '
+                            'they do not appear to match')
         return in_no
     in_no = axmap(coordmap, 'out2in', fix0=fix0)[axis_id]
     if in_no is None:
-        raise AxisError('Name "%s" present in output but this output axis '
-                        'does not have the best match with any input axis'
-                        % axis_id)
+        raise AxisError(f'Name "{axis_id}" present in output but this output axis '
+                        'does not have the best match with any input axis')
     return in_no
 
 
