@@ -15,6 +15,8 @@ __docformat__ = 'restructuredtext'
 
 import numpy as np
 
+from ...utils import SCTYPES
+
 
 class CoordinateSystemError(Exception):
     pass
@@ -74,8 +76,8 @@ class CoordinateSystem:
     dtype = np.dtype([('x', np.float64),
                       ('y', np.float64),
                       ('z', np.float64)])
-    _doc['dtype'] = 'The composite dtype of the CoordinateSystem, ' + \
-                    'expresses the fact that there are three numbers, the' + \
+    _doc['dtype'] = 'The composite dtype of the CoordinateSystem, ' \
+                    'expresses the fact that there are three numbers, the ' \
                     'first one corresponds to "x" and the second to "y".'
 
     def __init__(self, coord_names, name='', coord_dtype=np.float64):
@@ -115,8 +117,8 @@ class CoordinateSystem:
         if len(set(coord_names)) != len(coord_names):
             raise ValueError('coord_names must have distinct names')
         # verify that the dtype is coord_dtype for sanity
-        sctypes = (np.sctypes['int'] + np.sctypes['float'] +
-                   np.sctypes['complex'] + np.sctypes['uint'] + [object])
+        sctypes = (SCTYPES['int'] + SCTYPES['float'] +
+                   SCTYPES['complex'] + SCTYPES['uint'] + [object])
         coord_dtype = np.dtype(coord_dtype)
         if coord_dtype not in sctypes:
             raise ValueError(f'Coordinate dtype should be one of {sctypes}')
@@ -184,7 +186,7 @@ class CoordinateSystem:
         -------
         s : string
         """
-        return ("CoordinateSystem(coord_names={}, name='{}', coord_dtype={})".format(self.coord_names, self.name, self.coord_dtype))
+        return (f"CoordinateSystem(coord_names={self.coord_names}, name='{self.name}', coord_dtype={self.coord_dtype})")
 
 
     def _checked_values(self, arr):
@@ -276,12 +278,11 @@ class CoordinateSystem:
         '''
         arr = np.atleast_2d(arr)
         if arr.shape[-1] != self.ndim:
-            raise CoordinateSystemError('Array shape[-1] (%s) must match '
-                                        'CoordinateSystem ndim (%d).\n  %s'
-                                        % (arr.shape[-1], self.ndim, str(self)))
+            raise CoordinateSystemError(f'Array shape[-1] ({arr.shape[-1]}) must match '
+                                        f'CoordinateSystem ndim ({self.ndim}).\n  {self}')
         if not np.can_cast(arr.dtype, self.coord_dtype):
-            raise CoordinateSystemError('Cannot cast array dtype {} to '
-                                        'CoordinateSystem coord_dtype {}.\n  {}'.format(arr.dtype, self.coord_dtype, str(self)))
+            raise CoordinateSystemError(f'Cannot cast array dtype {arr.dtype} to '
+                                        f'CoordinateSystem coord_dtype {self.coord_dtype}.\n  {self}')
         return arr.reshape((-1, self.ndim))
 
 
@@ -333,7 +334,7 @@ def safe_dtype(*dtypes):
     Examples
     --------
     >>> c1 = CoordinateSystem('ij', 'input', coord_dtype=np.float32)
-    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex_)
+    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex128)
     >>> safe_dtype(c1.coord_dtype, c2.coord_dtype)
     dtype('complex128')
 
@@ -384,7 +385,7 @@ def product(*coord_systems, **kwargs):
     Examples
     --------
     >>> c1 = CoordinateSystem('ij', 'input', coord_dtype=np.float32)
-    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex_)
+    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex128)
     >>> c3 = CoordinateSystem('ik', 'in3')
 
     >>> print(product(c1, c2))
