@@ -1,10 +1,8 @@
-from __future__ import absolute_import
 
 import numpy as np
+import pytest
 from scipy.linalg import expm
 
-from nose.tools import assert_true, assert_equal, assert_raises
-
 import nipy.core.reference.tests.matrix_groups as MG
 from nipy.core.api import ArrayCoordMap
 
@@ -12,7 +10,7 @@ A = np.array([[0,1],
               [1,0]])
 
 B = np.array([[5,4],
-              [4,3]]) 
+              [4,3]])
 
 D = np.array([[25,4],
               [31,5]])
@@ -32,14 +30,14 @@ def test_init():
     SO_B = MG.O(B, 'xy')
 
     B[1] = -B[1]
-    assert_raises(ValueError, MG.SO, B, 'xy')
+    pytest.raises(ValueError, MG.SO, B, 'xy')
     O_B = MG.O(B, 'xy')
 
 def test2():
     Z = np.random.standard_normal((3,3))
     GL_Z = MG.GLR(Z, 'xyz')
 
-    assert_raises(ValueError, MG.SO, Z, 'zxy')
+    pytest.raises(ValueError, MG.SO, Z, 'zxy')
 
     detZ = np.linalg.det(Z)
     if detZ < 0:
@@ -65,12 +63,12 @@ def test_basis_change():
 
     basis1 = random_orth(names='xyz')
     basis2 = random_orth(names='uvw')
-    
+
     bchange = MG.Linear(basis2.coords, basis1.coords, random_orth(dim=3).matrix)
     #print basis1.coords
     new = MG.change_basis(basis1, bchange)
 
-    assert_true(MG.same_transformation(basis1, new, bchange))
+    assert MG.same_transformation(basis1, new, bchange)
 
 def test_product():
 
@@ -79,11 +77,10 @@ def test_product():
     GLZ_C = MG.GLZ(B, 'ij')
 
     GLZ_AB = MG.product(GLZ_A, GLZ_B)
-    yield (assert_true, 
-           np.allclose(GLZ_AB.matrix, np.dot(GLZ_A.matrix, GLZ_B.matrix)))
+    assert np.allclose(GLZ_AB.matrix, np.dot(GLZ_A.matrix, GLZ_B.matrix))
 
     # different coordinates: can't make the product
-    yield assert_raises, ValueError, MG.product, GLZ_A, GLZ_C
+    pytest.raises(ValueError, MG.product, GLZ_A, GLZ_C)
 
 def test_product2():
     O_1 = random_orth(names='xyz')
@@ -97,14 +94,14 @@ def test_homomorphism():
     GLZ_D = MG.GLZ(D, 'ij')
     GLZ_BD = MG.product_homomorphism(GLZ_B, GLZ_D)
 
-    yield assert_true, np.allclose(GLZ_BD.matrix[:2,:2], GLZ_B.matrix)
-    yield assert_true, np.allclose(GLZ_BD.matrix[2:,2:], GLZ_D.matrix)
-    yield assert_true, np.allclose(GLZ_BD.matrix[2:,:2], 0)
-    yield assert_true, np.allclose(GLZ_BD.matrix[:2,2:], 0)
+    assert np.allclose(GLZ_BD.matrix[:2,:2], GLZ_B.matrix)
+    assert np.allclose(GLZ_BD.matrix[2:,2:], GLZ_D.matrix)
+    assert np.allclose(GLZ_BD.matrix[2:,:2], 0)
+    assert np.allclose(GLZ_BD.matrix[:2,2:], 0)
 
     GLZ_C = MG.GLZ(D, 'xy')
     # have the same axisnames, an exception will be raised
-    yield assert_raises, ValueError, MG.product_homomorphism, GLZ_C, GLZ_B
+    pytest.raises(ValueError, MG.product_homomorphism, GLZ_C, GLZ_B)
 
     E = np.array([[7,8],
                   [8,9]])
@@ -118,7 +115,7 @@ def test_homomorphism():
 
     test1 = MG.product(GLZ_FE, GLZ_BD)
     test2 = MG.product_homomorphism(MG.product(GLZ_F, GLZ_B), MG.product(GLZ_E, GLZ_D))
-    yield assert_true, np.allclose(test1.matrix, test2.matrix)
+    assert np.allclose(test1.matrix, test2.matrix)
 
 
 def test_32():
@@ -138,7 +135,7 @@ def test_32():
     A = O32(a, 'xyz')
     B = O32(random_orth(3).matrix.astype(np.float32), 'xyz')
     C = MG.product(A, B)
-    yield assert_equal, C.dtype, np.float32
+    assert C.dtype == np.float32
 
     ev = ArrayCoordMap.from_shape(C, (20,30,40))
-    yield assert_equal, ev.values.dtype, np.float32
+    assert ev.values.dtype == np.float32
