@@ -1,3 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from files import load as load_image, save as save_image, as_image
+from .files import as_image
+from .files import load as load_image
+from .files import save as save_image
