@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 #emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
 #ex: set sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
@@ -13,4 +12,4 @@ warnings.warn('Please use nibabel instead of nipy.io.imageformats',
              DeprecationWarning,
              stacklevel=2)
 
-from nibabel import load, save, Nifti1Image
+from nibabel import Nifti1Image, load, save
