@@ -1,7 +1,7 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
-An implementation of some of the NIFTI conventions as desribed in:
+An implementation of some of the NIFTI conventions as described in:
 
 http://nifti.nimh.nih.gov/pub/dist/src/niftilib/nifti1.h
 
@@ -76,7 +76,7 @@ NIFTI input / output mapping
 ----------------------------
 
 NIFTI stores the relationship between the first 3 (spatial) voxel axes and the
-RAS+ coordinates in an *XYZ affine*.  This is a homogenous coordinate affine,
+RAS+ coordinates in an *XYZ affine*.  This is a homogeneous coordinate affine,
 hence 4 by 4 for 3 (spatial) dimensions.
 
 NIFTI also stores "pixel dimensions" in a ``pixdim`` field. This can give you
@@ -126,43 +126,38 @@ For saving a NIPY image to NIFTI, see the docstring for :func:`nipy2nifti`.
 For loading a NIFTI image to NIPY, see the docstring for :func:`nifti2nipy`.
 
 """
-from __future__ import absolute_import
 
 import sys
-
 import warnings
 from copy import copy
 
-import numpy as np
-
 import nibabel as nib
-from nibabel.affines import to_matvec, from_matvec
+import numpy as np
+from nibabel.affines import from_matvec, to_matvec
 
-from ..core.reference.coordinate_system import CoordinateSystem as CS
-from ..core.reference.coordinate_map import (AffineTransform as AT,
-                                             axmap,
-                                             product as cm_product)
-from ..core.reference import spaces as ncrs
 from ..core.image.image import Image
 from ..core.image.image_spaces import as_xyz_image
-
-from .nibcompat import get_header, get_affine
-
+from ..core.reference import spaces as ncrs
+from ..core.reference.coordinate_map import AffineTransform as AT
+from ..core.reference.coordinate_map import axmap
+from ..core.reference.coordinate_map import product as cm_product
+from ..core.reference.coordinate_system import CoordinateSystem as CS
+from .nibcompat import get_affine, get_header
 
 XFORM2SPACE = {'scanner': ncrs.scanner_space,
                'aligned': ncrs.aligned_space,
                'talairach': ncrs.talairach_space,
                'mni': ncrs.mni_space}
 
-TIME_LIKE_AXES = dict(
-    t = dict(aliases=('time',),
-             units='sec'),
-    hz = dict(aliases=('frequency-hz',),
-              units='hz'),
-    ppm = dict(aliases=('concentration-ppm',),
-               units='ppm'),
-    rads = dict(aliases=('radians/s',),
-                units='rads'))
+TIME_LIKE_AXES = {
+    't': {'aliases': ('time',),
+             'units': 'sec'},
+    'hz': {'aliases': ('frequency-hz',),
+              'units': 'hz'},
+    'ppm': {'aliases': ('concentration-ppm',),
+               'units': 'ppm'},
+    'rads': {'aliases': ('radians/s',),
+                'units': 'rads'}}
 
 TIME_LIKE_MAP = {}
 for _name, _info in TIME_LIKE_AXES.items():
@@ -286,8 +281,7 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
     except (ncrs.AxesError, ncrs.AffineError):
         # Python 2.5 / 3 compatibility
         e = sys.exc_info()[1]
-        raise NiftiError('Image cannot be reordered to XYZ because: "%s"'
-                         % e)
+        raise NiftiError(f'Image cannot be reordered to XYZ because: "{e}"')
     coordmap = img.coordmap
     # Get useful information from old header
     in_hdr = img.metadata.get('header', None)
@@ -297,7 +291,7 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
     data = None
     if data_dtype is None:
         if in_hdr is None:
-            data = img.get_data()
+            data = img.get_fdata()
             data_dtype = data.dtype
         else:
             data_dtype = in_hdr.get_data_dtype()
@@ -336,7 +330,7 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
                           stacklevel = 2)
             hdr.set_sform(xyz_affine, 'scanner')
             hdr.set_qform(xyz_affine, 'scanner')
-        elif not out_space in ncrs.unknown_space: # no space we recognize
+        elif out_space not in ncrs.unknown_space: # no space we recognize
             raise NiftiError('Image world not a NIFTI world')
         else: # unknown space requires affine that matches
             # Set guessed shape to set zooms correctly
@@ -351,22 +345,22 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
     # Use list() to get .index method for python < 2.6
     input_names = list(coordmap.function_domain.coord_names)
     spatial_names = input_names[:3]
-    dim_infos = []
-    for fps in 'freq', 'phase', 'slice':
-        dim_infos.append(
-            spatial_names.index(fps) if fps in spatial_names else None)
+    dim_infos = [
+        spatial_names.index(fps) if fps in spatial_names else None
+        for fps in ('freq', 'phase', 'slice')
+    ]
     hdr.set_dim_info(*dim_infos)
     # Set units without knowing time
     hdr.set_xyzt_units(xyz='mm')
     # Done if we only have 3 input dimensions
     n_ns = coordmap.ndims[0] - 3
     if n_ns == 0: # No non-spatial dimensions
-        return nib.Nifti1Image(img.get_data(), xyz_affine, hdr)
+        return nib.Nifti1Image(img.get_fdata(), xyz_affine, hdr)
     elif n_ns > 4:
         raise NiftiError("Too many dimensions to convert")
     # Go now to data, pixdims
     if data is None:
-        data = img.get_data()
+        data = img.get_fdata()
     rzs, trans = to_matvec(img.coordmap.affine)
     ns_pixdims = list(np.sqrt(np.sum(rzs[3:, 3:] ** 2, axis=0)))
     in_ax, out_ax, tl_name = _find_time_like(coordmap, fix0)
@@ -439,22 +433,22 @@ def _find_time_like(coordmap, fix0):
                 corr_in = out2in[same_time_out]
                 if corr_out is None:
                     if corr_in is not None:
-                        raise NiftiError("Axis type '%s' found in input and "
+                        raise NiftiError(f"Axis type '{name}' found in input and "
                                          "output but they do not appear to "
-                                         "match" % name)
+                                         "match")
                     return (in_ax, None, name)
                 if corr_out != same_time_out:
-                    raise NiftiError("Axis type '%s' found in input and "
+                    raise NiftiError(f"Axis type '{name}' found in input and "
                                      "output but they do not appear to "
-                                     "match" % name)
+                                     "match")
                 return (in_ax, corr_out, name)
             # Name not in output, but is there another time-like name at this
             # output position?
             matching = non_space_onames[corr_out - 3]
             if matching is None:
                 return (in_ax, corr_out, name)
-            raise NiftiError("Axis type '%s' in input matches axis type '%s' "
-                             "in output" % (name, matching))
+            raise NiftiError(f"Axis type '{name}' in input matches axis type '{matching}' "
+                             "in output")
         # Now check in output names
         elif name in non_space_onames:
             # Found name in output axes, corresponding input?
@@ -465,18 +459,18 @@ def _find_time_like(coordmap, fix0):
             matching = non_space_inames[in_ax - 3]
             if matching is None:
                 return (in_ax, out_ax, name)
-            raise NiftiError("Axis type '%s' in output matches axis type "
-                             "'%s' in input" % (name, matching))
+            raise NiftiError(f"Axis type '{name}' in output matches axis type "
+                             f"'{matching}' in input")
     return None, None, None
 
 
-TIME_LIKE_UNITS = dict(
-    sec = dict(name='t', scaling = 1),
-    msec = dict(name='t', scaling = 1 / 1000.),
-    usec = dict(name='t', scaling = 1 / 1000000.),
-    hz = dict(name='hz', scaling = 1),
-    ppm = dict(name='ppm', scaling = 1),
-    rads = dict(name='rads', scaling = 1))
+TIME_LIKE_UNITS = {
+    'sec': {'name': 't', 'scaling': 1},
+    'msec': {'name': 't', 'scaling': 1 / 1000.},
+    'usec': {'name': 't', 'scaling': 1 / 1000000.},
+    'hz': {'name': 'hz', 'scaling': 1},
+    'ppm': {'name': 'ppm', 'scaling': 1},
+    'rads': {'name': 'rads', 'scaling': 1}}
 
 
 def nifti2nipy(ni_img):
@@ -543,7 +537,7 @@ def nifti2nipy(ni_img):
         affine = hdr.get_best_affine()
     else:
         affine = affine.copy()
-    data = ni_img.get_data()
+    data = ni_img.get_fdata()
     shape = list(ni_img.shape)
     ndim = len(shape)
     if ndim < 3:
@@ -554,7 +548,7 @@ def nifti2nipy(ni_img):
     # For now we only warn if intent is set to an unexpected value
     intent, _, _ = hdr.get_intent()
     if intent != 'none':
-        warnings.warn('Ignoring intent field meaning "%s"' % intent,
+        warnings.warn(f'Ignoring intent field meaning "{intent}"',
                         UserWarning)
     # Which space?
     world_label = hdr.get_value_label('sform_code')
@@ -573,9 +567,9 @@ def nifti2nipy(ni_img):
     # Add to mm scaling, with warning
     space_units, time_like_units = hdr.get_xyzt_units()
     if space_units in ('micron', 'meter'):
-        warnings.warn('"%s" space scaling in NIFTI ``xyt_units field; '
+        warnings.warn(f'"{space_units}" space scaling in NIFTI ``xyt_units field; '
                       'applying scaling to affine, but this may not be what '
-                      'you want' % space_units, UserWarning)
+                      'you want', UserWarning)
         if space_units == 'micron':
             affine[:3] /= 1000.
         elif space_units == 'meter':
@@ -586,7 +580,7 @@ def nifti2nipy(ni_img):
     if ndim == 3:
         return Image(data, cmap3, {'header': hdr})
     space_units, time_like_units = hdr.get_xyzt_units()
-    units_info = TIME_LIKE_UNITS.get(time_like_units, None)
+    units_info = TIME_LIKE_UNITS.get(time_like_units)
     n_ns = ndim - 3
     ns_zooms = list(hdr.get_zooms()[3:])
     ns_trans = [0] * n_ns
