@@ -4,13 +4,10 @@
 This test can only be run from the directory above, as it uses relative
 imports.
 """
-from __future__ import absolute_import
-
-from nipy.testing import assert_equal
 
 import numpy as np
 
-from ..affine_utils import to_matrix_vector, from_matrix_vector
+from ..affine_utils import from_matrix_vector, to_matrix_vector
 
 
 def build_xform():
@@ -26,11 +23,11 @@ def build_xform():
 def test_to_matrix_vector():
     mat, vec, xform = build_xform()
     newmat, newvec = to_matrix_vector(xform)
-    yield assert_equal, newmat, mat
-    yield assert_equal, newvec, vec
+    np.testing.assert_array_equal(newmat, mat)
+    np.testing.assert_array_equal(newvec, vec)
 
 
 def test_from_matrix_vector():
     mat, vec, xform = build_xform()
     newxform = from_matrix_vector(mat, vec)
-    assert_equal, newxform, xform
+    np.testing.assert_array_equal(newxform, xform)
