@@ -6,11 +6,4 @@ by users at the application level. The image provides a coordinate map,
 and the data itself.
 
 """
-from __future__ import absolute_import
 __docformat__ = 'restructuredtext'
-
-
-from nipy.testing import Tester
-test = Tester().test
-bench = Tester().bench
-
