@@ -3,14 +3,15 @@
 """
 Testing volume data interface.
 """
-from __future__ import absolute_import
 
-import nose
 import copy
 
+import pytest
+
 # Local imports
 from ..volume_data import VolumeData
 
+
 ################################################################################
 # Tests
 def test_volume_data():
@@ -18,14 +19,13 @@ def test_volume_data():
     """
     vol = VolumeData()
     # Test that the repr doesn't raise an error
-    yield repr, vol
+    repr(vol)
 
     # Check the non-implemented interface
-    yield nose.tools.assert_raises, NotImplementedError, \
-                        vol.values_in_world, 0, 0, 0
+    pytest.raises(NotImplementedError,
+                        vol.values_in_world, 0, 0, 0)
 
-    yield nose.tools.assert_raises, NotImplementedError, \
-                        vol.as_volume_img
-
-    yield nose.tools.assert_raises, NotImplementedError, copy.copy, vol
+    pytest.raises(NotImplementedError,
+                        vol.as_volume_img)
 
+    pytest.raises(NotImplementedError, copy.copy, vol)
