@@ -9,12 +9,11 @@ import copy
 import numpy as np
 from scipy import ndimage
 
-# Local imports
-from ..transforms.affine_utils import to_matrix_vector, \
-                from_matrix_vector, get_bounds
 from ..transforms.affine_transform import AffineTransform
-from ..transforms.transform import CompositionError
 
+# Local imports
+from ..transforms.affine_utils import from_matrix_vector, get_bounds, to_matrix_vector
+from ..transforms.transform import CompositionError
 from .volume_grid import VolumeGrid
 
 ################################################################################
@@ -37,15 +36,15 @@ class VolumeImg(VolumeGrid):
         world_space : string
             Name of the world space the data is embedded in. For
             instance `mni152`.
-        metadata : dictionnary
-            Optional, user-defined, dictionnary used to carry around
+        metadata : dictionary
+            Optional, user-defined, dictionary used to carry around
             extra information about the data as it goes through
             transformations. The consistency of this information may not
             be maintained as the data is modified.
         interpolation : 'continuous' or 'nearest'
             String giving the interpolation logic used when calculating
             values in different world spaces
-        _data : 
+        _data :
             Private pointer to the data.
 
         Notes
@@ -54,10 +53,10 @@ class VolumeImg(VolumeGrid):
         The data is stored in an undefined way: prescalings might need to
         be applied to it before using it, or the data might be loaded on
         demand. The best practice to access the data is not to access the
-        _data attribute, but to use the `get_data` method.
+        _data attribute, but to use the `get_fdata` method.
     """
 
-    # most attributes are given by the VolumeField interface 
+    # most attributes are given by the VolumeField interface
 
     #---------------------------------------------------------------------------
     # Attributes, VolumeImg interface
@@ -70,7 +69,7 @@ class VolumeImg(VolumeGrid):
     # VolumeField interface
     #---------------------------------------------------------------------------
 
-    def __init__(self, data, affine, world_space, metadata=None, 
+    def __init__(self, data, affine, world_space, metadata=None,
                  interpolation='continuous'):
         """ Creates a new neuroimaging image with an affine mapping.
 
@@ -83,11 +82,11 @@ class VolumeImg(VolumeGrid):
                 affine transformation to the reference world space
             world_space : string
                 name of the reference world space.
-            metadata : dictionnary
-                dictionnary of user-specified information to store with
+            metadata : dictionary
+                dictionary of user-specified information to store with
                 the image.
         """
-        if not interpolation in ('continuous', 'nearest'):
+        if interpolation not in ('continuous', 'nearest'):
             raise ValueError('interpolation must be either continuous '
                              'or nearest')
         self._data = data
@@ -96,16 +95,16 @@ class VolumeImg(VolumeGrid):
         self.affine = affine
         self.world_space = world_space
         if metadata is None:
-            metadata = dict()
+            metadata = {}
         self.metadata = metadata
         self.interpolation = interpolation
 
-    
+
     def like_from_data(self, data):
         # Use self.__class__ for subclassing.
         assert len(data.shape) >= 3, \
             'The data passed must be an array of at least 3 dimensions'
-        return self.__class__(data=data, 
+        return self.__class__(data=data,
                               affine=copy.copy(self.affine),
                               world_space=self.world_space,
                               metadata=copy.copy(self.metadata),
@@ -134,13 +133,13 @@ class VolumeImg(VolumeGrid):
                 'The two images are not embedded in the same world space')
         if isinstance(target_image, VolumeImg):
             return self.as_volume_img(affine=target_image.affine,
-                                    shape=target_image.get_data().shape[:3],
+                                    shape=target_image.get_fdata().shape[:3],
                                     interpolation=interpolation)
         else:
-            # IMPORTANT: Polymorphism can be implemented by walking the 
+            # IMPORTANT: Polymorphism can be implemented by walking the
             # MRO and finding a method that does not raise
-            # NotImplementedError. 
-            return super(VolumeImg, self).resampled_to_img(target_image,
+            # NotImplementedError.
+            return super().resampled_to_img(target_image,
                                     interpolation=interpolation)
 
 
@@ -148,7 +147,7 @@ class VolumeImg(VolumeGrid):
     resampled_to_img.__doc__ = VolumeGrid.resampled_to_img.__doc__
 
 
-    def as_volume_img(self, affine=None, shape=None, 
+    def as_volume_img(self, affine=None, shape=None,
                                         interpolation=None, copy=True):
         if affine is None and shape is None:
             if copy:
@@ -158,7 +157,7 @@ class VolumeImg(VolumeGrid):
                 return self
         if affine is None:
             affine = self.affine
-        data = self.get_data()
+        data = self.get_fdata()
         if shape is None:
             shape = data.shape[:3]
         shape = list(shape)
@@ -168,11 +167,11 @@ class VolumeImg(VolumeGrid):
             affine4d = np.eye(4)
             affine4d[:3, :3] = affine
             transform_affine = np.dot(np.linalg.inv(affine4d),
-                                        self.affine, 
+                                        self.affine,
                                      )
             # The bounding box in the new world, if no offset is given
             (xmin, xmax), (ymin, ymax), (zmin, zmax) = get_bounds(
-                                                        data.shape[:3], 
+                                                        data.shape[:3],
                                                         transform_affine,
                                                         )
 
@@ -182,10 +181,10 @@ class VolumeImg(VolumeGrid):
             shape = (np.ceil(xmax - xmin)+1,
                      np.ceil(ymax - ymin)+1,
                      np.ceil(zmax - zmin)+1, )
+        shape = [int(s) for s in shape]
         if not len(shape) == 3:
             raise ValueError('The shape specified should be the shape '
-                'the 3D grid, and thus of length 3. %s was specified'
-                % shape )
+                f'the 3D grid, and thus of length 3. {shape} was specified' )
         interpolation_order = self._get_interpolation_order(interpolation)
         if np.all(affine == self.affine):
             # Small trick to be more numericaly stable
@@ -194,7 +193,7 @@ class VolumeImg(VolumeGrid):
             transform_affine = np.dot(np.linalg.inv(self.affine), affine)
         A, b = to_matrix_vector(transform_affine)
         A_inv = np.linalg.inv(A)
-        # If A is diagonal, ndimage.affine_transform is clever-enough 
+        # If A is diagonal, ndimage.affine_transform is clever-enough
         # to use a better algorithm
         if np.all(np.diag(np.diag(A)) == A):
             A = np.diag(A)
@@ -203,7 +202,7 @@ class VolumeImg(VolumeGrid):
         # For images with dimensions larger than 3D:
         data_shape = list(data.shape)
         if len(data_shape) > 3:
-            # Iter in a set of 3D volumes, as the interpolation problem is 
+            # Iter in a set of 3D volumes, as the interpolation problem is
             # separable in the extra dimensions. This reduces the
             # computational cost
             data = np.reshape(data, data_shape[:3] + [-1])
@@ -214,7 +213,7 @@ class VolumeImg(VolumeGrid):
                                                 order=interpolation_order)
                                 for slice in data]
             resampled_data = np.concatenate([d[..., np.newaxis]
-                                             for d in resampled_data], 
+                                             for d in resampled_data],
                                             axis=3)
             resampled_data = np.reshape(resampled_data, list(shape) +
                                             list(data_shape[3:]))
@@ -223,7 +222,7 @@ class VolumeImg(VolumeGrid):
                                                 offset=np.dot(A_inv, b),
                                                 output_shape=shape,
                                                 order=interpolation_order)
-        return self.__class__(resampled_data, affine, 
+        return self.__class__(resampled_data, affine,
                            self.world_space, metadata=self.metadata,
                            interpolation=self.interpolation)
 
@@ -238,7 +237,7 @@ class VolumeImg(VolumeGrid):
 
     def xyz_ordered(self, resample=False, copy=True):
         """ Returns an image with the affine diagonal and positive
-            in the world space it is embedded in. 
+            in the world space it is embedded in.
 
             Parameters
             -----------
@@ -277,8 +276,8 @@ class VolumeImg(VolumeGrid):
             axis_numbers = np.argmax(np.abs(A), axis=0)
 
         # Now make sure the affine is positive
-        pixdim = np.diag(A)
-        data = img.get_data()
+        pixdim = np.diag(A).copy()
+        data = img.get_fdata()
         if pixdim[0] < 0:
             b[0] = b[0] + pixdim[0]*(data.shape[0] - 1)
             pixdim[0] = -pixdim[0]
@@ -301,10 +300,10 @@ class VolumeImg(VolumeGrid):
         img._data = data
         img.affine = from_matrix_vector(np.diag(pixdim), b)
         return img
-    
+
 
     def _swapaxes(self, axis1, axis2):
-        """ Swap the axis axis1 and axis2 of the data array and reorder the 
+        """ Swap the axis axis1 and axis2 of the data array and reorder the
             affine matrix to stay consistent with the data
 
             See also
@@ -314,13 +313,13 @@ class VolumeImg(VolumeGrid):
         if (axis1 > 2) or (axis2 > 2):
             raise ValueError('Can swap axis only on spatial axis. '
                              'Use np.swapaxes of the data array.')
-        reordered_data = np.swapaxes(self.get_data(), axis1, axis2)
+        reordered_data = np.swapaxes(self.get_fdata(), axis1, axis2)
         new_affine = self.affine
         order = np.array((0, 1, 2, 3))
         order[axis1] = axis2
         order[axis2] = axis1
         new_affine = new_affine.T[order].T
-        return VolumeImg(reordered_data, new_affine, self.world_space, 
+        return VolumeImg(reordered_data, new_affine, self.world_space,
                                            metadata=self.metadata)
 
     #---------------------------------------------------------------------------
@@ -333,24 +332,24 @@ class VolumeImg(VolumeGrid):
         new_v2w_transform = \
                         self.get_transform().composed_with(w2w_transform)
         if hasattr(new_v2w_transform, 'affine'):
-            new_img = self.__class__(self.get_data(),
+            new_img = self.__class__(self.get_fdata(),
                                      new_v2w_transform.affine,
                                      new_v2w_transform.output_space,
                                      metadata=self.metadata,
                                      interpolation=self.interpolation)
         else:
-            new_img = VolumeGrid(self.get_data(),
+            new_img = VolumeGrid(self.get_fdata(),
                                 transform=new_v2w_transform,
                                 metadata=self.metadata,
                                 interpolation=self.interpolation)
-        return new_img 
+        return new_img
 
 
     def __repr__(self):
         options = np.get_printoptions()
         np.set_printoptions(precision=5, threshold=64, edgeitems=2)
         representation = \
-                '%s(\n  data=%s,\n  affine=%s,\n  world_space=%s,\n  interpolation=%s)' % (
+                '{}(\n  data={},\n  affine={},\n  world_space={},\n  interpolation={})'.format(
                 self.__class__.__name__,
                 '\n       '.join(repr(self._data).split('\n')),
                 '\n         '.join(repr(self.affine).split('\n')),
@@ -362,10 +361,8 @@ class VolumeImg(VolumeGrid):
 
     def __eq__(self, other):
         return (    isinstance(other, self.__class__)
-                and np.all(self.get_data() == other.get_data())
+                and np.all(self.get_fdata() == other.get_fdata())
                 and np.all(self.affine == other.affine)
                 and (self.world_space == other.world_space)
                 and (self.interpolation == other.interpolation)
                )
-
-
