@@ -11,13 +11,13 @@ Author : Bertrand Thirion, 2009-2011
          Virgile Fritsch <virgile.fritsch@inria.fr>
 
 """
-from __future__ import absolute_import
 
 import numpy as np
 
-from nipy.algorithms.graph.graph import WeightedGraph
-from nipy.algorithms.graph.forest import Forest
 from nipy.algorithms.graph.field import field_from_coo_matrix_and_data
+from nipy.algorithms.graph.forest import Forest
+from nipy.algorithms.graph.graph import WeightedGraph
+
 from .mroi import SubDomains
 
 NINF = - np.inf
@@ -156,7 +156,7 @@ class HierarchicalROI(SubDomains):
     ----------
     k : int
       Number of ROI in the SubDomains object
-    label : array of shape (domain.size), dtype=np.int
+    label : array of shape (domain.size), dtype=np.int_
       An array use to define which voxel belongs to which ROI.
       The label values greater than -1 correspond to subregions
       labelling. The labels are recomputed so as to be consecutive
@@ -180,7 +180,7 @@ class HierarchicalROI(SubDomains):
         """Building the HierarchicalROI
         """
         SubDomains.__init__(self, domain, label, id=id)
-        self.parents = np.ravel(parents).astype(np.int)
+        self.parents = np.ravel(parents).astype(np.int_)
 
     ###
     # Getters for very basic features or roi features
@@ -297,7 +297,7 @@ class HierarchicalROI(SubDomains):
         else:
             # get new parents
             new_parents = Forest(self.k, self.parents).subforest(
-                valid.astype(np.bool)).parents.astype(np.int)
+                valid.astype(np.bool_)).parents.astype(np.int_)
         SubDomains.select_roi(self, id_list)
         self.parents = new_parents
         self.recompute_labels()
@@ -341,7 +341,7 @@ class HierarchicalROI(SubDomains):
             return
         id_list = [k for k in self.get_id() if k in id_list]
 
-        # relabel maps old labels to new labels 
+        # relabel maps old labels to new labels
         relabel = np.arange(self.k)
 
         # merge nodes, one at a time
@@ -353,7 +353,7 @@ class HierarchicalROI(SubDomains):
 
             if p_pos != c_pos:
                 # this will be used in many places
-                mask_pos = np.ones(self.k, np.bool)
+                mask_pos = np.ones(self.k, np.bool_)
                 mask_pos[c_pos] = False
 
                 # set new parents
@@ -370,7 +370,7 @@ class HierarchicalROI(SubDomains):
                     # replace feature
                     # (without the API since self is in an inconsistent state)
                     dj = self.get_feature(fid)
-                    dj[p_pos] = np.hstack((dj[self.select_id(c_id)], 
+                    dj[p_pos] = np.hstack((dj[self.select_id(c_id)],
                                            dj[self.select_id(p_id)]))
                     del dj[c_pos]
                     self.features[fid] = dj
@@ -383,7 +383,7 @@ class HierarchicalROI(SubDomains):
                         dj[p_pos] = dj[c_pos]
                     self.roi_features[fid] = dj[mask_pos]
 
-        # update the labels        
+        # update the labels
         self.label[self.label > -1] = relabel[self.label[self.label > - 1]]
         self.recompute_labels()
 
@@ -405,7 +405,7 @@ class HierarchicalROI(SubDomains):
         if self.k == 0:
             return
 
-        # relabel maps old labels to new labels 
+        # relabel maps old labels to new labels
         relabel = np.arange(self.k)
 
         # merge nodes, one at a time
@@ -423,7 +423,7 @@ class HierarchicalROI(SubDomains):
                 # merge node if it has only one child
                 c_pos = p_children[0]
                 c_id = self.get_id()[c_pos]
-                mask_pos = np.ones(self.k, np.bool)
+                mask_pos = np.ones(self.k, np.bool_)
                 mask_pos[p_pos] = False
 
                 # set new parents
@@ -441,7 +441,7 @@ class HierarchicalROI(SubDomains):
                     # replace feature
                     # (without the API since self is in an inconsistent state)
                     dj = self.get_feature(fid)
-                    dj[c_pos] = np.hstack((dj[self.select_id(c_id)], 
+                    dj[c_pos] = np.hstack((dj[self.select_id(c_id)],
                                            dj[self.select_id(p_id)]))
                     del dj[p_pos]
                     self.features[fid] = dj
@@ -482,18 +482,18 @@ class HierarchicalROI(SubDomains):
         is_leaf = np.asarray(
             [(len(child) == 0) or (len(child) == 1 and child[0] == i)
              for i, child in enumerate(is_leaf_aux)])
-        # finaly return ids
+        # finally return ids
         return self.get_id()[is_leaf]
 
     def reduce_to_leaves(self):
         """Create a  new set of rois which are only the leaves of self.
 
         Modification of the structure is done in place. One way therefore
-        want to work on a copy a of a given HROI oject.
+        want to work on a copy a of a given HROI object.
 
         """
         if self.k == 0:
-            # handle the empy HROI case
+            # handle the empty HROI case
             return HierarchicalROI(
                 self.domain, -np.ones(self.domain.size), np.array([]))
         leaves_id = self.get_leaves_id()
@@ -588,7 +588,7 @@ class HierarchicalROI(SubDomains):
             summary_feature = rf
 
         if assess_quality:
-            self.set_roi_feature('%s_quality' % fid, feature_quality)
+            self.set_roi_feature(f'{fid}_quality', feature_quality)
         return np.array(summary_feature)
 
 
