@@ -12,8 +12,6 @@ Group Studies.  IEEE TMI 2007
 
 Author : Bertrand Thirion, 2006-2013
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 #autoindent
 
@@ -33,7 +31,7 @@ def _threshold_weight_map(x, fraction):
     return x
 
 
-class LandmarkRegions(object):
+class LandmarkRegions:
     """
     This class is intended to represent a set of inter-subject regions
     It should inherit from some abstract multiple ROI class,
@@ -112,7 +110,7 @@ class LandmarkRegions(object):
 
     def map_label(self, coord=None, pval=1., sigma=1.):
         """Sample the set of landmark regions
-        on the proposed coordiante set cs, assuming a Gaussian shape
+        on the proposed coordinate set cs, assuming a Gaussian shape
 
         Parameters
         ----------
@@ -183,9 +181,9 @@ def build_landmarks(domain, coords, subjects, labels, confidence=None,
             description of the spatial context of the landmarks
     coords: array of shape(n, 3)
             Sets of coordinates for the different objects
-    subjects: array of shape (n), dtype = np.int
+    subjects: array of shape (n), dtype = np.int_
               indicators of the dataset the objects come from
-    labels: array of shape (n), dtype = np.int
+    labels: array of shape (n), dtype = np.int_
             index of the landmark the object is associated with
     confidence: array of shape (n),
                 measure of the significance of the regions
@@ -215,7 +213,7 @@ def build_landmarks(domain, coords, subjects, labels, confidence=None,
     subjs = []
     pps = []
     n_labels = int(labels.max() + 1)
-    valid = np.zeros(n_labels).astype(np.int)
+    valid = np.zeros(n_labels).astype(np.int_)
 
     # do some computation to find which regions are worth reporting
     for i in np.unique(labels[labels > - 1]):
@@ -243,7 +241,7 @@ def build_landmarks(domain, coords, subjects, labels, confidence=None,
             pps.append(confidence[labels == i])
 
     # relabel the ROIs
-    maplabel = - np.ones(n_labels).astype(np.int)
+    maplabel = - np.ones(n_labels).astype(np.int_)
     maplabel[valid > 0] = np.cumsum(valid[valid > 0]) - 1
 
     # create the landmark regions structure
