@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import numpy as np
@@ -8,13 +7,15 @@ import scipy.stats as sp_stats
 from nibabel import Nifti1Image as Image
 from nibabel.affines import apply_affine
 
-from ..io.nibcompat import get_affine
 from ..algorithms.graph.field import field_from_graph_and_data
 from ..algorithms.graph.graph import wgraph_from_3d_grid
 from ..algorithms.statistics import empirical_pvalue
+from ..io.nibcompat import get_affine
 from .glm import glm
-from .group.permutation_test import \
-     permutation_test_onesample, permutation_test_twosample
+from .group.permutation_test import (
+    permutation_test_onesample,
+    permutation_test_twosample,
+)
 
 # FIXME: rename permutation_test_onesample class
 #so that name starts with upper case
@@ -57,11 +58,11 @@ def cluster_stats(zimg, mask, height_th, height_control='fpr',
     """
     # Masking
     if len(mask.shape) > 3:
-        xyz = np.where((mask.get_data() > 0).squeeze())
-        zmap = zimg.get_data().squeeze()[xyz]
+        xyz = np.where((mask.get_fdata() > 0).squeeze())
+        zmap = zimg.get_fdata().squeeze()[xyz]
     else:
-        xyz = np.where(mask.get_data() > 0)
-        zmap = zimg.get_data()[xyz]
+        xyz = np.where(mask.get_fdata() > 0)
+        zmap = zimg.get_fdata()[xyz]
 
     xyz = np.array(xyz).T
     nvoxels = np.size(xyz, 0)
@@ -107,11 +108,11 @@ def cluster_stats(zimg, mask, height_th, height_control='fpr',
     fdr_pvalue = empirical_pvalue.gaussian_fdr(zmap)[above_th]
 
     # Default "nulls"
-    if not 'zmax' in nulls:
+    if 'zmax' not in nulls:
         nulls['zmax'] = 'bonferroni'
-    if not 'smax' in nulls:
+    if 'smax' not in nulls:
         nulls['smax'] = None
-    if not 's' in nulls:
+    if 's' not in nulls:
         nulls['s'] = None
 
     # Report significance levels in each cluster
@@ -183,12 +184,12 @@ def get_3d_peaks(image, mask=None, threshold=0., nn=18, order_th=0):
     """
     # Masking
     if mask is not None:
-        bmask = mask.get_data().ravel()
-        data = image.get_data().ravel()[bmask > 0]
+        bmask = mask.get_fdata().ravel()
+        data = image.get_fdata().ravel()[bmask > 0]
         xyz = np.array(np.where(bmask > 0)).T
     else:
         shape = image.shape
-        data = image.get_data().ravel()
+        data = image.get_fdata().ravel()
         xyz = np.reshape(np.indices(shape), (3, np.prod(shape))).T
     affine = get_affine(image)
 
@@ -235,12 +236,12 @@ def prepare_arrays(data_images, vardata_images, mask_images):
      # Compute xyz coordinates from mask
     xyz = np.array(np.where(mask > 0))
     # Prepare data & vardata arrays
-    data = np.array([(d.get_data()[xyz[0], xyz[1], xyz[2]]).squeeze()
+    data = np.array([(d.get_fdata()[xyz[0], xyz[1], xyz[2]]).squeeze()
                     for d in data_images]).squeeze()
     if vardata_images is None:
         vardata = None
     else:
-        vardata = np.array([(d.get_data()[xyz[0], xyz[1], xyz[2]]).squeeze()
+        vardata = np.array([(d.get_fdata()[xyz[0], xyz[1], xyz[2]]).squeeze()
                             for d in vardata_images]).squeeze()
     return data, vardata, xyz, mask
 
@@ -261,7 +262,7 @@ def onesample_test(data_images, vardata_images, mask_images, stat_id,
 
     # Compute z-map image
     zmap = np.zeros(data_images[0].shape).squeeze()
-    zmap[list(xyz)] = ptest.zscore()
+    zmap[tuple(xyz)] = ptest.zscore()
     zimg = Image(zmap, get_affine(data_images[0]))
 
     # Compute mask image
@@ -310,7 +311,7 @@ def twosample_test(data_images, vardata_images, mask_images, labels, stat_id,
 
     # Compute z-map image
     zmap = np.zeros(data_images[0].shape).squeeze()
-    zmap[list(xyz)] = ptest.zscore()
+    zmap[tuple(xyz)] = ptest.zscore()
     zimg = Image(zmap, get_affine(data_images[0]))
 
     # Compute mask image
@@ -357,13 +358,13 @@ def linear_model_fit(data_images, mask_images, design_matrix, vector):
 
     # Compute z-map image
     zmap = np.zeros(data_images[0].shape).squeeze()
-    zmap[list(xyz)] = c.zscore()
+    zmap[tuple(xyz)] = c.zscore()
     zimg = Image(zmap, get_affine(data_images[0]))
 
     return zimg
 
 
-class LinearModel(object):
+class LinearModel:
 
     def_model = 'spherical'
     def_niter = 2
@@ -386,7 +387,7 @@ class LinearModel(object):
             self.xyz = None
             self.axis = len(data[0].shape) - 1
         else:
-            self.xyz = np.where(mask.get_data() > 0)
+            self.xyz = np.where(mask.get_fdata() > 0)
             self.axis = 1
 
         self.spatial_shape = data[0].shape[0: -1]
@@ -397,9 +398,9 @@ class LinearModel(object):
             if not isinstance(design_matrix[i], np.ndarray):
                 raise ValueError('Invalid design matrix')
             if nomask:
-                Y = data[i].get_data()
+                Y = data[i].get_fdata()
             else:
-                Y = data[i].get_data()[self.xyz]
+                Y = data[i].get_fdata()[self.xyz]
             X = design_matrix[i]
 
             self.glm.append(glm(Y, X, axis=self.axis,
@@ -443,6 +444,6 @@ class LinearModel(object):
 
 
 ###############################################################################
-# Hack to have nose skip onesample_test, which is not a unit test
+# Hack to have test framework skip onesample_test, which is not a unit test
 onesample_test.__test__ = False
 twosample_test.__test__ = False
