@@ -6,34 +6,25 @@ The Slicer classes.
 The main purpose of these classes is to have auto adjust of axes size to
 the data with different layout of cuts.
 """
-from __future__ import absolute_import
 
+import matplotlib as mpl
+import matplotlib.pyplot as plt
 import numpy as np
+from matplotlib import transforms
 
 from nipy.utils import is_iterable
 
-from nipy.utils.skip_test import skip_if_running_nose
-
-try:
-    import matplotlib as mpl
-    import pylab as pl
-    from matplotlib import transforms
-except ImportError:
-    skip_if_running_nose('Could not import matplotlib')
-
-
 # Local imports
-from .coord_tools import coord_transform, get_bounds, get_mask_bounds, \
-        find_cut_coords
-from .edge_detect import _edge_map
-from . import cm
 from ..datasets import VolumeImg
+from . import cm
+from .coord_tools import coord_transform, find_cut_coords, get_bounds, get_mask_bounds
+from .edge_detect import _edge_map
 
 ################################################################################
 # Bugware to have transparency work OK with MPL < .99.1
 if mpl.__version__ < '0.99.1':
-    # We wrap the lut as a callable and replace its evalution to put
-    # alpha to zero where the mask is true. This is what is done in
+    # We wrap the lut as a callable and replace its evaluation to put
+    # alpha to zero where the mask is true. This is what is done if
     # MPL >= .99.1
     from matplotlib import colors
     class CMapProxy(colors.Colormap):
@@ -57,7 +48,7 @@ if mpl.__version__ < '0.99.1':
 def _xyz_order(map, affine):
     img = VolumeImg(map, affine=affine, world_space='mine')
     img = img.xyz_ordered(resample=True, copy=False)
-    map = img.get_data()
+    map = img.get_fdata()
     affine = img.affine
     return map, affine
 
@@ -66,7 +57,7 @@ def _xyz_order(map, affine):
 # class CutAxes
 ################################################################################
 
-class CutAxes(object):
+class CutAxes:
     """ An MPL axis-like object that displays a cut of 3D volumes
     """
 
@@ -80,12 +71,12 @@ class CutAxes(object):
             direction: {'x', 'y', 'z'}
                 The directions of the cut
             coord: float
-                The coordinnate along the direction of the cut
+                The coordinate along the direction of the cut
         """
         self.ax = ax
         self.direction = direction
         self.coord = coord
-        self._object_bounds = list()
+        self._object_bounds = []
 
 
     def do_cut(self, map, affine):
@@ -100,11 +91,11 @@ class CutAxes(object):
         """
         coords = [0, 0, 0]
         coords['xyz'.index(self.direction)] = self.coord
-        x_map, y_map, z_map = [int(np.round(c)) for c in
+        x_map, y_map, z_map = (int(np.round(c)) for c in
                                coord_transform(coords[0],
                                                coords[1],
                                                coords[2],
-                                               np.linalg.inv(affine))]
+                                               np.linalg.inv(affine)))
         if self.direction == 'y':
             cut = np.rot90(map[:, y_map, :])
         elif self.direction == 'x':
@@ -112,8 +103,7 @@ class CutAxes(object):
         elif self.direction == 'z':
             cut = np.rot90(map[:, :, z_map])
         else:
-            raise ValueError('Invalid value for direction %s' %
-                             self.direction)
+            raise ValueError(f'Invalid value for direction {self.direction}')
         return cut
 
 
@@ -123,7 +113,7 @@ class CutAxes(object):
         kwargs['origin'] = 'upper'
         if mpl.__version__ < '0.99.1':
             cmap = kwargs.get('cmap',
-                        pl.cm.cmap_d[pl.rcParams['image.cmap']])
+                        plt.cm.cmap_d[plt.rcParams['image.cmap']])
             kwargs['cmap'] = CMapProxy(cmap)
 
         if self.direction == 'y':
@@ -136,8 +126,7 @@ class CutAxes(object):
             (xmin, xmax), (zmin, zmax), (_, _) = data_bounds
             (xmin_, xmax_), (zmin_, zmax_), (_, _) = bounding_box
         else:
-            raise ValueError('Invalid value for direction %s' %
-                             self.direction)
+            raise ValueError(f'Invalid value for direction {self.direction}')
         ax = self.ax
         getattr(ax, type)(cut, extent=(xmin, xmax, zmin, zmax), **kwargs)
 
@@ -168,8 +157,8 @@ class CutAxes(object):
                 horizontalalignment='left',
                 verticalalignment='top',
                 size=size,
-                bbox=dict(boxstyle="square,pad=0",
-                            ec=bg_color, fc=bg_color, alpha=1),
+                bbox={'boxstyle': "square,pad=0",
+                            'ec': bg_color, 'fc': bg_color, 'alpha': 1},
                 **kwargs)
 
         ax.text(.9, .95, 'R',
@@ -177,8 +166,8 @@ class CutAxes(object):
                 horizontalalignment='right',
                 verticalalignment='top',
                 size=size,
-                bbox=dict(boxstyle="square,pad=0",
-                            ec=bg_color, fc=bg_color, alpha=1),
+                bbox={'boxstyle': "square,pad=0",
+                            'ec': bg_color, 'fc': bg_color, 'alpha': 1},
                 **kwargs)
 
 
@@ -189,8 +178,8 @@ class CutAxes(object):
                 horizontalalignment='left',
                 verticalalignment='bottom',
                 size=size,
-                bbox=dict(boxstyle="square,pad=0",
-                            ec=bg_color, fc=bg_color, alpha=1),
+                bbox={'boxstyle': "square,pad=0",
+                            'ec': bg_color, 'fc': bg_color, 'alpha': 1},
                 **kwargs)
 
 
@@ -198,7 +187,7 @@ class CutAxes(object):
 # class BaseSlicer
 ################################################################################
 
-class BaseSlicer(object):
+class BaseSlicer:
     """ The main purpose of these class is to have auto adjust of axes size
         to the data with different layout of cuts.
     """
@@ -216,14 +205,14 @@ class BaseSlicer(object):
                 The axes that will be subdivided in 3.
             black_bg: boolean, optional
                 If True, the background of the figure will be put to
-                black. If you whish to save figures with a black background, 
-                you will need to pass "facecolor='k', edgecolor='k'" to 
-                pylab's savefig.
+                black. If you wish to save figures with a black background,
+                you will need to pass "facecolor='k', edgecolor='k'" to
+                pyplot's savefig.
 
         """
         self._cut_coords = cut_coords
         if axes is None:
-            axes = pl.axes((0., 0., 1., 1.))
+            axes = plt.axes((0., 0., 1., 1.))
             axes.axis('off')
         self.frame_axes = axes
         axes.set_zorder(1)
@@ -246,10 +235,10 @@ class BaseSlicer(object):
                          black_bg=False, leave_space=False):
         cut_coords = cls.find_cut_coords(data, affine, threshold,
                                          cut_coords)
-        if isinstance(axes, pl.Axes) and figure is None:
+        if isinstance(axes, plt.Axes) and figure is None:
             figure = axes.figure
 
-        if not isinstance(figure, pl.Figure):
+        if not isinstance(figure, plt.Figure):
             # Make sure that we have a figure
             figsize = cls._default_figsize[:]
             # Adjust for the number of axes
@@ -258,10 +247,10 @@ class BaseSlicer(object):
 
             if leave_space:
                 figsize[0] += 3.4
-            figure = pl.figure(figure, figsize=figsize,
+            figure = plt.figure(figure, figsize=figsize,
                             facecolor=facecolor)
         else:
-            if isinstance(axes, pl.Axes):
+            if isinstance(axes, plt.Axes):
                 assert axes.figure is figure, ("The axes passed are not "
                 "in the figure")
 
@@ -286,10 +275,10 @@ class BaseSlicer(object):
             text: string
                 The text of the title
             x: float, optional
-                The horizontal position of the title on the frame in 
+                The horizontal position of the title on the frame in
                 fraction of the frame width.
             y: float, optional
-                The vertical position of the title on the frame in 
+                The vertical position of the title on the frame in
                 fraction of the frame height.
             size: integer, optional
                 The size of the title text.
@@ -307,13 +296,13 @@ class BaseSlicer(object):
             color = 'k' if self._black_bg else 'w'
         if bgcolor is None:
             bgcolor = 'w' if self._black_bg else 'k'
-        self.frame_axes.text(x, y, text, 
+        self.frame_axes.text(x, y, text,
                     transform=self.frame_axes.transAxes,
                     horizontalalignment='left',
                     verticalalignment='top',
                     size=size, color=color,
-                    bbox=dict(boxstyle="square,pad=.3", 
-                              ec=bgcolor, fc=bgcolor, alpha=alpha),
+                    bbox={'boxstyle': "square,pad=.3",
+                              'ec': bgcolor, 'fc': bgcolor, 'alpha': alpha},
                     **kwargs)
 
 
@@ -339,7 +328,7 @@ class BaseSlicer(object):
             if threshold == 0:
                 map = np.ma.masked_equal(map, 0, copy=False)
             else:
-                map = np.ma.masked_inside(map, -threshold, threshold, 
+                map = np.ma.masked_inside(map, -threshold, threshold,
                                           copy=False)
 
         self._map_show(map, affine, type='imshow', **kwargs)
@@ -388,9 +377,9 @@ class BaseSlicer(object):
                 if kwargs.get('max') is None:
                     kwargs['vmax'] = vmax
         else:
-            if not 'vmin' in kwargs:
+            if 'vmin' not in kwargs:
                 kwargs['vmin'] = map.min()
-            if not 'vmax' in kwargs:
+            if 'vmax' not in kwargs:
                 kwargs['vmax'] = map.max()
 
         bounding_box = (xmin_, xmax_), (ymin_, ymax_), (zmin_, zmax_)
@@ -421,7 +410,7 @@ class BaseSlicer(object):
                 The color used to display the edge map
         """
         map, affine = _xyz_order(map, affine)
-        kwargs = dict(cmap=cm.alpha_cmap(color=color))
+        kwargs = {'cmap': cm.alpha_cmap(color=color)}
         data_bounds = get_bounds(map.shape, affine)
 
         # For each ax, cut the data and plot it
@@ -453,7 +442,7 @@ class BaseSlicer(object):
                 function.
         """
         kwargs = kwargs.copy()
-        if not 'color' in kwargs:
+        if 'color' not in kwargs:
             if self._black_bg:
                 kwargs['color'] = 'w'
             else:
@@ -482,7 +471,7 @@ class OrthoSlicer(BaseSlicer):
         Attributes
         ----------
 
-        axes: dictionnary of axes
+        axes: dictionary of axes
             The 3 axes used to plot each view.
         frame_axes: axes
             The axes framing the whole set of views.
@@ -509,9 +498,9 @@ class OrthoSlicer(BaseSlicer):
     def _init_axes(self):
         x0, y0, x1, y1 = self.rect
         # Create our axes:
-        self.axes = dict()
+        self.axes = {}
         for index, direction in enumerate(('y', 'x', 'z')):
-            ax = pl.axes([0.3*index*(x1-x0) + x0, y0, .3*(x1-x0), y1-y0])
+            ax = plt.axes([0.3*index*(x1-x0) + x0, y0, .3*(x1-x0), y1-y0])
             ax.axis('off')
             coord = self._cut_coords['xyz'.index(direction)]
             cut_ax = CutAxes(ax, direction, coord)
@@ -524,7 +513,7 @@ class OrthoSlicer(BaseSlicer):
             Here we put the logic used to adjust the size of the axes.
         """
         x0, y0, x1, y1 = self.rect
-        width_dict = dict()
+        width_dict = {}
         cut_ax_dict = self.axes
         x_ax = cut_ax_dict['x']
         y_ax = cut_ax_dict['y']
@@ -533,7 +522,7 @@ class OrthoSlicer(BaseSlicer):
             bounds = cut_ax.get_object_bounds()
             if not bounds:
                 # This happens if the call to _map_show was not
-                # succesful. As it happens asyncroniously (during a
+                # successful. As it happens asyncroniously (during a
                 # refresh of the figure) we capture the problem and
                 # ignore it: it only adds a non informative traceback
                 bounds = [0, 1, 0, 1]
@@ -542,7 +531,7 @@ class OrthoSlicer(BaseSlicer):
         total_width = float(sum(width_dict.values()))
         for ax, width in width_dict.items():
             width_dict[ax] = width/total_width*(x1 -x0)
-        left_dict = dict()
+        left_dict = {}
         left_dict[y_ax.ax] = x0
         left_dict[x_ax.ax] = x0 + width_dict[y_ax.ax]
         left_dict[z_ax.ax] = x0 + width_dict[x_ax.ax] + width_dict[y_ax.ax]
@@ -558,7 +547,7 @@ class OrthoSlicer(BaseSlicer):
             ----------
             cut_coords: 3-tuple of floats, optional
                 The position of the cross to draw. If none is passed, the
-                ortho_slicer's cut coordinnates are used.
+                ortho_slicer's cut coordinates are used.
             kwargs:
                 Extra keyword arguments are passed to axhline
         """
@@ -566,7 +555,7 @@ class OrthoSlicer(BaseSlicer):
             cut_coords = self._cut_coords
         x, y, z = cut_coords
         kwargs = kwargs.copy()
-        if not 'color' in kwargs:
+        if 'color' not in kwargs:
             if self._black_bg:
                 kwargs['color'] = '.8'
             else:
@@ -588,11 +577,11 @@ class OrthoSlicer(BaseSlicer):
 def demo_ortho_slicer():
     """ A small demo of the OrthoSlicer functionality.
     """
-    pl.clf()
+    plt.clf()
     oslicer = OrthoSlicer(cut_coords=(0, 0, 0))
     from .anat_cache import _AnatCache
     map, affine, _ = _AnatCache.get_anat()
-    oslicer.plot_map(map, affine, cmap=pl.cm.gray)
+    oslicer.plot_map(map, affine, cmap=plt.cm.gray)
     return oslicer
 
 
@@ -607,7 +596,7 @@ class BaseStackedSlicer(BaseSlicer):
         Attributes
         ----------
 
-        axes: dictionnary of axes
+        axes: dictionary of axes
             The axes used to plot each view.
         frame_axes: axes
             The axes framing the whole set of views.
@@ -648,11 +637,11 @@ class BaseStackedSlicer(BaseSlicer):
     def _init_axes(self):
         x0, y0, x1, y1 = self.rect
         # Create our axes:
-        self.axes = dict()
+        self.axes = {}
         fraction = 1./len(self._cut_coords)
         for index, coord in enumerate(self._cut_coords):
             coord = float(coord)
-            ax = pl.axes([fraction*index*(x1-x0) + x0, y0,
+            ax = plt.axes([fraction*index*(x1-x0) + x0, y0,
                           fraction*(x1-x0), y1-y0])
             ax.axis('off')
             cut_ax = CutAxes(ax, self._direction, coord)
@@ -665,13 +654,13 @@ class BaseStackedSlicer(BaseSlicer):
             Here we put the logic used to adjust the size of the axes.
         """
         x0, y0, x1, y1 = self.rect
-        width_dict = dict()
+        width_dict = {}
         cut_ax_dict = self.axes
         for cut_ax in cut_ax_dict.values():
             bounds = cut_ax.get_object_bounds()
             if not bounds:
                 # This happens if the call to _map_show was not
-                # succesful. As it happens asyncroniously (during a
+                # successful. As it happens asyncroniously (during a
                 # refresh of the figure) we capture the problem and
                 # ignore it: it only adds a non informative traceback
                 bounds = [0, 1, 0, 1]
@@ -680,7 +669,7 @@ class BaseStackedSlicer(BaseSlicer):
         total_width = float(sum(width_dict.values()))
         for ax, width in width_dict.items():
             width_dict[ax] = width/total_width*(x1 -x0)
-        left_dict = dict()
+        left_dict = {}
         left = float(x0)
         for coord, cut_ax in sorted(cut_ax_dict.items()):
             left_dict[cut_ax.ax] = left
@@ -698,7 +687,7 @@ class BaseStackedSlicer(BaseSlicer):
             ----------
             cut_coords: 3-tuple of floats, optional
                 The position of the cross to draw. If none is passed, the
-                ortho_slicer's cut coordinnates are used.
+                ortho_slicer's cut coordinates are used.
             kwargs:
                 Extra keyword arguments are passed to axhline
         """
@@ -719,7 +708,7 @@ class ZSlicer(BaseStackedSlicer):
     _direction = 'z'
 
 
-SLICERS = dict(ortho=OrthoSlicer,
-               x=XSlicer,
-               y=YSlicer,
-               z=ZSlicer)
+SLICERS = {'ortho': OrthoSlicer,
+               'x': XSlicer,
+               'y': YSlicer,
+               'z': ZSlicer}
