@@ -1,21 +1,15 @@
-from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-import nose
 
+import pytest
 
 try:
-    import matplotlib as mp
-    # Make really sure that we don't try to open an Xserver connection.
-    mp.use('svg')
-    import pylab as pl
-    pl.switch_backend('svg')
+    import matplotlib as mpl
 except ImportError:
-    raise nose.SkipTest('Could not import matplotlib')
-
-from ..slicers import demo_ortho_slicer
+    pytest.skip("Could not import matplotlib", allow_module_level=True)
 
 from ..anat_cache import find_mni_template
+from ..slicers import demo_ortho_slicer
 
 ################################################################################
 # Some smoke testing for graphics-related code
@@ -24,10 +18,9 @@ def test_demo_ortho_slicer():
     # This is only a smoke test
     # conditioned on presence of MNI templated
     if not find_mni_template():
-        raise nose.SkipTest("MNI Template is absent for the smoke test")
-    mp.use('svg')
-    import pylab as pl
-    pl.switch_backend('svg')
+        pytest.skip("MNI Template is absent for the smoke test")
+    # Make really sure that we don't try to open an Xserver connection.
+    mpl.use('svg')
+    import matplotlib.pyplot as plt
+    plt.switch_backend('svg')
     demo_ortho_slicer()
-
-
