@@ -1,7 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
 
@@ -23,13 +21,13 @@ class FmriImageList(ImageList):
         images : iterable
            an iterable object whose items are meant to be images; this is
            checked by asserting that each has a `coordmap` attribute and a
-           ``get_data`` method.  Note that Image objects are not iterable by
+           ``get_fdata`` method.  Note that Image objects are not iterable by
            default; use the ``from_image`` classmethod or ``iter_axis`` function
            to convert images to image lists - see examples below for the latter.
         volume_start_times: None or float or (N,) ndarray
             start time of each frame. It can be specified either as an ndarray
             with ``N=len(images)`` elements or as a single float, the TR. None
-            results in ``np.arange(len(images)).astype(np.float)``
+            results in ``np.arange(len(images)).astype(np.float64)``
         slice_times: None or (N,) ndarray
             specifying offset for each slice of each frame, from the frame start
             time.
@@ -68,7 +66,7 @@ class FmriImageList(ImageList):
         If index is an index, return self.list[index], an Image
         else return an FmriImageList with images=self.list[index].
         """
-        if type(index) is type(1):
+        if type(index) is int:
             return self.list[index]
         return self.__class__(
             images=self.list[index],
@@ -89,7 +87,7 @@ class FmriImageList(ImageList):
         volume_start_times: None or float or (N,) ndarray
             start time of each frame. It can be specified either as an ndarray
             with ``N=len(images)`` elements or as a single float, the TR. None
-            results in ``np.arange(len(images)).astype(np.float)``
+            results in ``np.arange(len(images)).astype(np.float64)``
         slice_times: None or (N,) ndarray
             specifying offset for each slice of each frame, from the frame start
             time.
@@ -135,4 +133,3 @@ def axis0_generator(data, slicers=None):
         slicers = range(arr.shape[1])
     for slicer in slicers:
         yield slicer, arr[:,slicer]
-
