@@ -1,3 +1,5 @@
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 """
 This module is meant to reproduce the GLM analysis of fmristat.
 
@@ -6,7 +8,3 @@ TODO fix reference here
 
 """
 __docformat__ = 'restructuredtext'
-
-from nipy.testing import Tester
-test = Tester().test
-bench = Tester().bench
