@@ -1,17 +1,12 @@
 """ Tests for regression module
 """
-from __future__ import absolute_import
 
 import numpy as np
+from numpy.testing import assert_array_almost_equal
 
-from nipy.algorithms.statistics.api  import OLSModel
-from ..outputters import output_T, output_F
-
-from nose.tools import assert_true, assert_equal, assert_raises
-
-from numpy.testing import (assert_array_almost_equal,
-                           assert_array_equal)
+from nipy.algorithms.statistics.api import OLSModel
 
+from ..outputters import output_F, output_T
 
 N = 10
 X = np.c_[np.linspace(-1,1,N), np.ones((N,))]
