@@ -29,23 +29,17 @@ Example of fixed effects statistics across two contrasts
 >>> np.random.shuffle(cval_)
 >>> z_ffx = (model.contrast(cval) + model.contrast(cval_)).z_score()
 """
-from __future__ import print_function
-from __future__ import absolute_import
-
-import numpy as np
 
 from warnings import warn
 
+import numpy as np
 import scipy.stats as sps
+from nibabel import Nifti1Image, load
 
-from nibabel import load, Nifti1Image
-
-from nipy.io.nibcompat import get_header, get_affine
-from nipy.labs.mask import compute_mask_sessions
-from nipy.algorithms.statistics.models.regression import OLSModel, ARModel
+from nipy.algorithms.statistics.models.regression import ARModel, OLSModel
 from nipy.algorithms.statistics.utils import multiple_mahalanobis, z_score
-
-from nipy.externals.six import string_types
+from nipy.io.nibcompat import get_affine, get_header
+from nipy.labs.mask import compute_mask_sessions
 
 DEF_TINY = 1e-50
 DEF_DOFMAX = 1e10
@@ -71,13 +65,13 @@ def data_scaling(Y):
     return Y, mean
 
 
-class GeneralLinearModel(object):
+class GeneralLinearModel:
     """ This class handles the so-called on General Linear Model
 
     Most of what it does in the fit() and contrast() methods
     fit() performs the standard two-step ('ols' then 'ar1') GLM fitting
     contrast() returns a contrast instance, yileding statistics and p-values.
-    The link between fit() and constrast is done vis the two class members:
+    The link between fit() and contrast is done vis the two class members:
 
     glm_results : dictionary of nipy.algorithms.statistics.models.
                  regression.RegressionResults instances,
@@ -125,9 +119,9 @@ class GeneralLinearModel(object):
         # compute and discretize the AR1 coefs
         ar1 = ((ols_result.resid[1:] * ols_result.resid[:-1]).sum(0) /
                (ols_result.resid ** 2).sum(0))
-        ar1 = (ar1 * steps).astype(np.int) * 1. / steps
+        ar1 = (ar1 * steps).astype(np.int_) * 1. / steps
 
-        # Fit the AR model acccording to current AR(1) estimates
+        # Fit the AR model according to current AR(1) estimates
         if model == 'ar1':
             self.results_ = {}
             self.labels_ = ar1
@@ -161,8 +155,8 @@ class GeneralLinearModel(object):
         n_beta = len(column_index)
 
         # build the beta array
-        beta = np.zeros((n_beta, self.labels_.size), dtype=np.float)
-        for l in self.results_.keys():
+        beta = np.zeros((n_beta, self.labels_.size), dtype=np.float64)
+        for l in self.results_:
             beta[:, self.labels_ == l] = self.results_[l].theta[column_index]
         return beta
 
@@ -175,8 +169,8 @@ class GeneralLinearModel(object):
             the sum of square error per voxel
         """
         # build the beta array
-        mse = np.zeros(self.labels_.size, dtype=np.float)
-        for l in self.results_.keys():
+        mse = np.zeros(self.labels_.size, dtype=np.float64)
+        for l in self.results_:
             mse[self.labels_ == l] = self.results_[l].MSE
         return mse
 
@@ -189,8 +183,8 @@ class GeneralLinearModel(object):
             the sum of square error per voxel
         """
         # build the beta array
-        logL = np.zeros(self.labels_.size, dtype=np.float)
-        for l in self.results_.keys():
+        logL = np.zeros(self.labels_.size, dtype=np.float64)
+        for l in self.results_:
             logL[self.labels_ == l] = self.results_[l].logL
         return logL
 
@@ -222,17 +216,17 @@ class GeneralLinearModel(object):
             else:
                 contrast_type = 'F'
         if contrast_type not in ['t', 'F', 'tmin-conjunction']:
-            raise ValueError('Unknown contrast type: %s' % contrast_type)
+            raise ValueError(f'Unknown contrast type: {contrast_type}')
 
-        effect_ = np.zeros((dim, self.labels_.size), dtype=np.float)
-        var_ = np.zeros((dim, dim, self.labels_.size), dtype=np.float)
+        effect_ = np.zeros((dim, self.labels_.size), dtype=np.float64)
+        var_ = np.zeros((dim, dim, self.labels_.size), dtype=np.float64)
         if contrast_type == 't':
-            for l in self.results_.keys():
+            for l in self.results_:
                 resl = self.results_[l].Tcontrast(con_val)
                 effect_[:, self.labels_ == l] = resl.effect.T
                 var_[:, :, self.labels_ == l] = (resl.sd ** 2).T
         else:
-            for l in self.results_.keys():
+            for l in self.results_:
                 resl = self.results_[l].Fcontrast(con_val)
                 effect_[:, self.labels_ == l] = resl.effect
                 var_[:, :, self.labels_ == l] = resl.covariance
@@ -242,7 +236,7 @@ class GeneralLinearModel(object):
                         contrast_type=contrast_type)
 
 
-class Contrast(object):
+class Contrast:
     """ The contrast class handles the estimation of statistical contrasts
     on a given model: student (t), Fisher (F), conjunction (tmin-conjunction).
     The important feature is that it supports addition,
@@ -250,7 +244,7 @@ class Contrast(object):
 
     The current implementation is meant to be simple,
     and could be enhanced in the future on the computational side
-    (high-dimensional F constrasts may lead to memory breakage).
+    (high-dimensional F contrasts may lead to memory breakage).
 
     Notes
     -----
@@ -286,7 +280,7 @@ class Contrast(object):
         self.variance = variance
         self.dof = float(dof)
         self.dim = effect.shape[0]
-        if self.dim > 1 and contrast_type is 't':
+        if self.dim > 1 and contrast_type == 't':
             print('Automatically converted multi-dimensional t to F contrast')
             contrast_type = 'F'
         self.contrast_type = contrast_type
@@ -321,7 +315,7 @@ class Contrast(object):
                 self.effect = self.effect[np.newaxis]
             if self.variance.ndim == 1:
                 self.variance = self.variance[np.newaxis, np.newaxis]
-            stat = (multiple_mahalanobis(self.effect - baseline, 
+            stat = (multiple_mahalanobis(self.effect - baseline,
                                           self.variance) / self.dim)
         # Case: tmin (conjunctions)
         elif self.contrast_type == 'tmin-conjunction':
@@ -331,7 +325,7 @@ class Contrast(object):
                 np.maximum(vdiag, self.tiny))
             stat = stat.min(0)
 
-        # Unknwon stat
+        # Unknown stat
         else:
             raise ValueError('Unknown statistic type')
         self.stat_ = stat
@@ -350,7 +344,7 @@ class Contrast(object):
         -----
         The value of 0.5 is used where the stat is not defined
         """
-        if self.stat_ is None or not self.baseline == baseline:
+        if self.stat_ is None or self.baseline != baseline:
             self.stat_ = self.stat(baseline)
         # Valid conjunction as in Nichols et al, Neuroimage 25, 2005.
         if self.contrast_type in ['t', 'tmin-conjunction']:
@@ -378,7 +372,7 @@ class Contrast(object):
         -----
         The value of 0 is used where the stat is not defined
         """
-        if self.p_value_ is None or not self.baseline == baseline:
+        if self.p_value_ is None or self.baseline != baseline:
             self.p_value_ = self.p_value(baseline)
 
         # Avoid inf values kindly supplied by scipy.
@@ -391,7 +385,7 @@ class Contrast(object):
         This should be used only on indepndent contrasts"""
         if self.contrast_type != other.contrast_type:
             raise ValueError(
-                'The two contrasts do not have consistant type dimensions')
+                'The two contrasts do not have consistent type dimensions')
         if self.dim != other.dim:
             raise ValueError(
                 'The two contrasts do not have compatible dimensions')
@@ -416,7 +410,7 @@ class Contrast(object):
         return self.__rmul__(1 / float(scalar))
 
 
-class FMRILinearModel(object):
+class FMRILinearModel:
     """ This class is meant to handle GLMs from a higher-level perspective
     i.e. by taking images as input and output
     """
@@ -461,12 +455,12 @@ class FMRILinearModel(object):
             z_image, = multi_session_model.contrast([np.eye(13)[1]] * 2)
 
             # The number of voxels with p < 0.001 given by ...
-            print(np.sum(z_image.get_data() > 3.09))
+            print(np.sum(z_image.get_fdata() > 3.09))
         """
         # manipulate the arguments
-        if isinstance(fmri_data, string_types) or hasattr(fmri_data, 'get_data'):
+        if isinstance(fmri_data, str) or hasattr(fmri_data, 'get_fdata'):
             fmri_data = [fmri_data]
-        if isinstance(design_matrices, (string_types, np.ndarray)):
+        if isinstance(design_matrices, (str, np.ndarray)):
             design_matrices = [design_matrices]
         if len(fmri_data) != len(design_matrices):
             raise ValueError('Incompatible number of fmri runs and '
@@ -476,7 +470,7 @@ class FMRILinearModel(object):
 
         # load the fmri data
         for fmri_run in fmri_data:
-            if isinstance(fmri_run, string_types):
+            if isinstance(fmri_run, str):
                 self.fmri_data.append(load(fmri_run))
             else:
                 self.fmri_data.append(fmri_run)
@@ -485,7 +479,7 @@ class FMRILinearModel(object):
 
         # load the designs
         for design_matrix in design_matrices:
-            if isinstance(design_matrix, string_types):
+            if isinstance(design_matrix, str):
                 loaded = np.load(design_matrix)
                 self.design_matrices.append(loaded[loaded.files[0]])
             else:
@@ -500,7 +494,7 @@ class FMRILinearModel(object):
             mask = np.ones(self.fmri_data[0].shape[:3]).astype(np.int8)
             self.mask = Nifti1Image(mask, self.affine)
         else:
-            if isinstance(mask, string_types):
+            if isinstance(mask, str):
                 self.mask = load(mask)
             else:
                 self.mask = mask
@@ -519,16 +513,16 @@ class FMRILinearModel(object):
         """
         from nibabel import Nifti1Image
         # get the mask as an array
-        mask = self.mask.get_data().astype(np.bool)
+        mask = self.mask.get_fdata().astype(np.bool_)
 
         self.glms, self.means = [], []
         for fmri, design_matrix in zip(self.fmri_data, self.design_matrices):
             if do_scaling:
                 # scale the data
-                data, mean = data_scaling(fmri.get_data()[mask].T)
+                data, mean = data_scaling(fmri.get_fdata()[mask].T)
             else:
-                data, mean = (fmri.get_data()[mask].T,
-                              fmri.get_data()[mask].T.mean(0))
+                data, mean = (fmri.get_fdata()[mask].T,
+                              fmri.get_fdata()[mask].T.mean(0))
             mean_data = mask.astype(np.int16)
             mean_data[mask] = mean
             self.means.append(Nifti1Image(mean_data, self.affine))
@@ -572,8 +566,7 @@ class FMRILinearModel(object):
             contrasts = [contrasts]
         if len(contrasts) != len(self.glms):
             raise ValueError(
-                'contrasts must be a sequence of %d session contrasts' %
-                len(self.glms))
+                f'contrasts must be a sequence of {len(self.glms)} session contrasts')
 
         contrast_ = None
         for i, (glm, con) in enumerate(zip(self.glms, contrasts)):
@@ -588,7 +581,7 @@ class FMRILinearModel(object):
             contrast_.z_score()
 
         # Prepare the returned images
-        mask = self.mask.get_data().astype(np.bool)
+        mask = self.mask.get_fdata().astype(np.bool_)
         do_outputs = [output_z, output_stat, output_effects, output_variance]
         estimates = ['z_score_', 'stat_', 'effect', 'variance']
         descrips = ['z statistic', 'Statistical value', 'Estimated effect',
@@ -601,15 +594,15 @@ class FMRILinearModel(object):
             if do_output:
                 if dim > 1:
                     result_map = np.tile(
-                        mask.astype(np.float)[:, :, :, np.newaxis], dim)
+                        mask.astype(np.float64)[:, :, :, np.newaxis], dim)
                     result_map[mask] = np.reshape(
                         getattr(contrast_, estimate).T, (n_vox, dim))
                 else:
-                    result_map = mask.astype(np.float)
+                    result_map = mask.astype(np.float64)
                     result_map[mask] = np.squeeze(
                         getattr(contrast_, estimate))
                 output = Nifti1Image(result_map, self.affine)
                 get_header(output)['descrip'] = (
-                    '%s associated with contrast %s' % (descrip, con_id))
+                    f'{descrip} associated with contrast {con_id}')
                 output_images.append(output)
         return output_images
