@@ -1,11 +1,10 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
 from numpy.linalg import inv
 
+
 def ARcovariance(rho, n, cor=False, sigma=1.):
     """
     Return covariance matrix of a sample of length n from an AR(p)
@@ -18,7 +17,7 @@ def ARcovariance(rho, n, cor=False, sigma=1.):
     """
 
     rho = np.asarray(rho)
-    p = rho.shape[0] 
+    p = rho.shape[0]
     invK = np.identity(n)
     for i in range(p):
         invK -= np.diag((rho[i] / sigma) * np.ones(n-i-1), k=-i-1)
@@ -47,7 +46,7 @@ def ARcomponents(rho, n, drho=0.05, cor=False, sigma=1):
     value = []
 
     if drho.shape == ():
-        drho = np.ones(p, np.float) * drho
+        drho = np.ones(p, np.float64) * drho
     drho = np.diag(drho)
 
     Q = ARcovariance(rho, n, cor=cor, sigma=sigma)
