@@ -1,16 +1,16 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-import gc, os, fpformat, time
 
 import numpy as np
 import numpy.linalg as L
 from scipy.stats import f as FDbn
-from nipy.algorithms.statistics.models.regression import OLSModel, GLSModel
 
+from nipy.algorithms.statistics.models.regression import GLSModel, OLSModel
 from nipy.core.api import Image
 from nipy.modalities.fmri.fmristat import model as fmristat
 from nipy.modalities.fmri.fmristat.model import OLS
-import correlation, reml
+
+from . import correlation, reml
 
 
 def Fmask(Fimg, dfnum, dfdenom, pvalue=1.0e-04):
@@ -21,7 +21,7 @@ def Fmask(Fimg, dfnum, dfdenom, pvalue=1.0e-04):
 
     ## TODO check nipy.algorithms.statistics.models.contrast to see if rank is
     ## correctly set -- I don't think it is right now.
-    print dfnum, dfdenom
+    print(dfnum, dfdenom)
     thresh = FDbn.ppf(pvalue, dfnum, dfdenom)
     return Image(np.greater(np.asarray(Fimg), thresh), Fimg.grid.copy())
 
@@ -29,12 +29,12 @@ def Fmask(Fimg, dfnum, dfdenom, pvalue=1.0e-04):
 def estimate_pooled_covariance(resid, ARtarget=[0.3], mask=None):
     """
     Use SPM's REML implementation to estimate a pooled covariance matrix.
-    
+
     Thresholds an F statistic at a marginal pvalue to estimate
     covariance matrix.
 
     """
-    resid 
+    resid
     n = resid[:].shape[0]
     components = correlation.ARcomponents(ARtarget, n)
 
@@ -42,9 +42,9 @@ def estimate_pooled_covariance(resid, ARtarget=[0.3], mask=None):
     nvox = 0
     for i in range(resid.shape[1]):
         d = np.asarray(resid[:,i])
-        d.shape = (d.shape[0], np.product(d.shape[1:]))
+        d.shape = (d.shape[0], np.prod(d.shape[1:]))
         keep = np.asarray(mask[i])
-        keep.shape = np.product(keep.shape)
+        keep.shape = np.prod(keep.shape)
         d = d.compress(keep, axis=1)
         raw_sigma += np.dot(d, d.T)
         nvox += d.shape[1]
@@ -54,7 +54,7 @@ def estimate_pooled_covariance(resid, ARtarget=[0.3], mask=None):
                         n=nvox)
     return C
 
-class SecondStage(object):
+class SecondStage:
     """
     Parameters
     ----------
@@ -63,9 +63,9 @@ class SecondStage(object):
        ``volume_start_times`` (if `volume_start_times` is None), and
        such that ``object[0]`` returns something with attributes ``shape``
     formula :  :class:`nipy.algorithms.statistics.formula.Formula`
-    sigma : 
+    sigma :
     outputs :
-    volume_start_times : 
+    volume_start_times :
     """
 
     def __init__(self, fmri_image, formula, sigma, outputs=[],
@@ -99,20 +99,18 @@ class SecondStage(object):
             These passes are i) 'slices through the z-axis'
                             ii) 'parcels of approximately constant AR1 coefficient'
             """
-    
+
             if len(x.shape) == 2:
-                if type(i) is type(1):
-                    x.shape = (x.shape[0],) + self.fmri_image[0].shape[1:]                        
+                if type(i) is int:
+                    x.shape = (x.shape[0],) + self.fmri_image[0].shape[1:]
                 if type(i) not in [type([]), type(())]:
                     i = (i,)
                 else:
                     i = tuple(i)
                 i = (slice(None,None,None),) + tuple(i)
             else:
-                if type(i) is type(1):
+                if type(i) is int:
                     x.shape = self.fmri_image[0].shape[1:]
             return i, x
 
         o = fmristat.generate_output(self.outputs, r, reshape=reshape)
-
-
