@@ -1,13 +1,12 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
 from numpy.linalg import svd
 
 from .reml import orth
 
+
 def _trace(x):
     """
     Trace of a square 2d array.
@@ -56,7 +55,7 @@ def trRV(X=None, V=None):
 
     if V is None:
         V = np.identity(n)
-        
+
     if X is None:
         if V is None:
             trRV = trRVRV = n
