@@ -7,20 +7,22 @@ Note that the tests just looks whether the data produces has correct dimension,
 not whether it is exact
 """
 
-from __future__ import with_statement
-from __future__ import absolute_import
+import os.path as osp
+from unittest import skipIf
 
 import numpy as np
-import os.path as osp
+from numpy.testing import assert_almost_equal, assert_array_equal
+
+from ..design_matrix import (
+    _convolve_regressors,
+    _cosine_drift,
+    dmtx_from_csv,
+    dmtx_light,
+    make_dmtx,
+)
+
 #from os.path import join, dirname, walk
-from ..experimental_paradigm import (EventRelatedParadigm, BlockParadigm)
-from ..design_matrix import (dmtx_light, _convolve_regressors, dmtx_from_csv,
-                             make_dmtx, _cosine_drift)
-
-from nibabel.tmpdirs import InTemporaryDirectory
-
-from nose.tools import assert_true, assert_equal
-from numpy.testing import assert_almost_equal, dec, assert_array_equal
+from ..experimental_paradigm import BlockParadigm, EventRelatedParadigm
 
 try:
     import matplotlib.pyplot
@@ -65,7 +67,7 @@ def block_paradigm():
     return paradigm
 
 
-@dec.skipif(not have_mpl)
+@skipIf(not have_mpl, reason="Needs matplotlib")
 def test_show_dmtx():
     # test that the show code indeed (formally) runs
     frametimes = np.linspace(0, 127 * 1.,128)
@@ -79,7 +81,7 @@ def test_show_dmtx():
 
 def test_cosine_drift():
     # add something so that when the tests are launched from a different directory
-    # we still find the file ' 'dctmtx_N_20_order_4.txt' ? 
+    # we still find the file ' 'dctmtx_N_20_order_4.txt' ?
 
     spm_drifts = DMTX['cosbf_dt_1_nt_20_hcut_0p1'] # np.loadtxt('dctmtx_N_20_order_4.txt')
     tim = np.arange(20)
@@ -89,7 +91,7 @@ def test_cosine_drift():
     # nipy_drifts is placing the constant at the end [:,:-1]
 
 
-@dec.skipif(not have_mpl)
+@skipIf(not have_mpl, reason="Needs matplotlib")
 def test_show_constrast():
     # test that the show code indeed (formally) runs
     frametimes = np.linspace(0, 127 * 1.,128)
@@ -109,7 +111,7 @@ def test_dmtx0():
     frametimes = np.linspace(0, 127 * tr,128)
     X, names= dmtx_light(frametimes, drift_model='polynomial',
                             drift_order=3)
-    assert_equal(len(names), 4)
+    assert len(names) == 4
 
 
 def test_dmtx0b():
@@ -138,10 +140,10 @@ def test_dmtx0d():
     ax = np.random.randn(128, 4)
     X, names= dmtx_light(frametimes, drift_model='polynomial',
                             drift_order=3, add_regs=ax)
-    assert_equal(len(names), 8)
-    assert_equal(X.shape[1], 8)
+    assert len(names) == 8
+    assert X.shape[1] == 8
+
 
-    
 def test_dmtx1():
     # basic test based on basic_paradigm and canonical hrf
     tr = 1.0
@@ -150,7 +152,7 @@ def test_dmtx1():
     hrf_model = 'Canonical'
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                             drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 7)
+    assert len(names) == 7
 
 
 def test_convolve_regressors():
@@ -161,7 +163,7 @@ def test_convolve_regressors():
     # names not passed -> default names
     frametimes = np.arange(100)
     f, names = _convolve_regressors(paradigm, 'canonical', frametimes)
-    assert_equal(names, ['c0', 'c1'])
+    assert names == ['c0', 'c1']
 
 
 def test_dmtx1b():
@@ -173,7 +175,7 @@ def test_dmtx1b():
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                         drift_model='polynomial', drift_order=3)
 
-    assert_equal(X.shape, (128, 7))
+    assert X.shape == (128, 7)
 
 
 def test_dmtx1c():
@@ -184,7 +186,7 @@ def test_dmtx1c():
     hrf_model = 'Canonical'
     X,names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                         drift_model='polynomial', drift_order=3)
-    assert_true((X[:, - 1] == 1).all())
+    assert (X[:, - 1] == 1).all()
 
 
 def test_dmtx1d():
@@ -195,8 +197,8 @@ def test_dmtx1d():
     hrf_model = 'Canonical'
     X,names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                         drift_model='polynomial', drift_order=3)
-    assert_true((np.isnan(X) == 0).all())
-       
+    assert (np.isnan(X) == 0).all()
+
 def test_dmtx2():
     # idem test_dmtx1 with a different drift term
     tr = 1.0
@@ -205,7 +207,7 @@ def test_dmtx2():
     hrf_model = 'Canonical'
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                         drift_model='cosine', hfcut=63)
-    assert_equal(len(names), 7) # was 8 with old cosine
+    assert len(names) == 7 # was 8 with old cosine
 
 def test_dmtx3():
     # idem test_dmtx1 with a different drift term
@@ -215,7 +217,7 @@ def test_dmtx3():
     hrf_model = 'Canonical'
     X,names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                         drift_model='blank')
-    assert_equal(len(names), 4)  
+    assert len(names) == 4
 
 def test_dmtx4():
     # idem test_dmtx1 with a different hrf model
@@ -225,7 +227,7 @@ def test_dmtx4():
     hrf_model = 'Canonical With Derivative'
     X, names= dmtx_light(frametimes, paradigm, hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 10)
+    assert len(names) == 10
 
 def test_dmtx5():
     # idem test_dmtx1 with a block paradigm
@@ -235,7 +237,7 @@ def test_dmtx5():
     hrf_model = 'Canonical'
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 7)
+    assert len(names) == 7
 
 def test_dmtx6():
     # idem test_dmtx1 with a block paradigm and the hrf derivative
@@ -245,7 +247,7 @@ def test_dmtx6():
     hrf_model = 'Canonical With Derivative'
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 10)
+    assert len(names) == 10
 
 def test_dmtx7():
     # idem test_dmtx1, but odd paradigm
@@ -258,7 +260,7 @@ def test_dmtx7():
     hrf_model = 'Canonical'
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                           drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 7)
+    assert len(names) == 7
 
 def test_dmtx8():
     # basic test based on basic_paradigm and FIR
@@ -268,7 +270,7 @@ def test_dmtx8():
     hrf_model = 'FIR'
     X, names= dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    assert_equal(len(names), 7)
+    assert len(names) == 7
 
 def test_dmtx9():
     # basic test based on basic_paradigm and FIR
@@ -279,7 +281,7 @@ def test_dmtx9():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                             drift_model='polynomial', drift_order=3,
                             fir_delays=list(range(1, 5)))
-    assert_equal(len(names), 16)
+    assert len(names) == 16
 
 def test_dmtx10():
     # Check that the first column o FIR design matrix is OK
@@ -290,8 +292,8 @@ def test_dmtx10():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3,
                          fir_delays=list(range(1, 5)))
-    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int)
-    assert_true(np.all((X[onset + 1, 0] == 1)))
+    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_)
+    assert np.all(X[onset + 1, 0] == 1)
 
 
 def test_dmtx11():
@@ -303,8 +305,8 @@ def test_dmtx11():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3,
                          fir_delays=list(range(1, 5)))
-    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int)
-    assert_true(np.all(X[onset + 3, 2] == 1))
+    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_)
+    assert np.all(X[onset + 3, 2] == 1)
 
 
 def test_dmtx12():
@@ -316,8 +318,8 @@ def test_dmtx12():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3,
                          fir_delays=list(range(1, 5)))
-    onset = paradigm.onset[paradigm.con_id == 'c2'].astype(np.int)
-    assert_true(np.all(X[onset + 4, 11] == 1))
+    onset = paradigm.onset[paradigm.con_id == 'c2'].astype(np.int_)
+    assert np.all(X[onset + 4, 11] == 1)
 
 
 def test_dmtx13():
@@ -329,8 +331,8 @@ def test_dmtx13():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                           drift_model='polynomial', drift_order=3,
                           fir_delays=list(range(1, 5)))
-    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int)
-    assert_true(np.all(X[onset + 1, 0] == 1))
+    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_)
+    assert np.all(X[onset + 1, 0] == 1)
 
 
 def test_dmtx14():
@@ -343,12 +345,12 @@ def test_dmtx14():
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3,
                          fir_delays=list(range(1, 5)))
-    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int)
-    assert_true(np.all(X[onset + 1, 0] > .9))
+    onset = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_)
+    assert np.all(X[onset + 1, 0] > .9)
 
 
 def test_dmtx15():
-    # basic test based on basic_paradigm, plus user supplied regressors 
+    # basic test based on basic_paradigm, plus user supplied regressors
     tr = 1.0
     frametimes = np.linspace(0, 127 * tr, 128)
     paradigm = basic_paradigm()
@@ -356,8 +358,8 @@ def test_dmtx15():
     ax = np.random.randn(128, 4)
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3, add_regs=ax)
-    assert_equal(len(names), 11)
-    assert_equal(X.shape[1], 11)
+    assert len(names) == 11
+    assert X.shape[1] == 11
 
 def test_dmtx16():
     # Check that additional regressors are put at the right place
@@ -379,8 +381,8 @@ def test_dmtx17():
     hrf_model = 'Canonical'
     X, names = dmtx_light(frametimes, paradigm,  hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    ct = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int) + 1
-    assert_true((X[ct, 0] > 0).all())
+    ct = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_) + 1
+    assert (X[ct, 0] > 0).all()
 
 
 def test_dmtx18():
@@ -391,8 +393,8 @@ def test_dmtx18():
     hrf_model = 'Canonical'
     X, names = dmtx_light(frametimes, paradigm, hrf_model=hrf_model,
                          drift_model='polynomial', drift_order=3)
-    ct = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int) + 3
-    assert_true((X[ct, 0] > 0).all())
+    ct = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_) + 3
+    assert (X[ct, 0] > 0).all()
 
 
 def test_dmtx19():
@@ -404,19 +406,19 @@ def test_dmtx19():
     X, names = dmtx_light(frametimes, paradigm, hrf_model=hrf_model,
                           drift_model='polynomial', drift_order=3,
                           fir_delays=list(range(1, 5)))
-    idx = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int)
+    idx = paradigm.onset[paradigm.con_id == 'c0'].astype(np.int_)
     assert_array_equal(X[idx + 1, 0], X[idx + 2, 1])
 
 
 def test_dmtx20():
     # Test for commit 10662f7
-    frametimes = np.arange(0, 128) # was 127 in old version of _cosine_drift 
+    frametimes = np.arange(0, 128) # was 127 in old version of _cosine_drift
     paradigm = modulated_event_paradigm()
     X, names = dmtx_light(frametimes, paradigm, hrf_model='canonical',
         drift_model='cosine')
 
     # check that the drifts are not constant
-    assert_true(np.all(np.diff(X[:, -2]) != 0))
+    assert np.all(np.diff(X[:, -2]) != 0)
 
 
 def test_fir_block():
@@ -425,16 +427,16 @@ def test_fir_block():
     tr = 1.0
     frametimes = np.linspace(0, 127 * tr, 128)
     X, names = dmtx_light(frametimes, bp, hrf_model='fir', drift_model='blank',
-                          fir_delays=list(range(0, 4)))
-    idx = bp.onset[bp.con_id == 'c1'].astype(np.int)
-    assert_equal(X.shape, (128, 13))
-    assert_true((X[idx, 4] == 1).all())
-    assert_true((X[idx + 1, 5] == 1).all())
-    assert_true((X[idx + 2, 6] == 1).all())
-    assert_true((X[idx + 3, 7] == 1).all())
+                          fir_delays=list(range(4)))
+    idx = bp.onset[bp.con_id == 'c1'].astype(np.int_)
+    assert X.shape == (128, 13)
+    assert (X[idx, 4] == 1).all()
+    assert (X[idx + 1, 5] == 1).all()
+    assert (X[idx + 2, 6] == 1).all()
+    assert (X[idx + 3, 7] == 1).all()
 
 
-def test_csv_io():
+def test_csv_io(in_tmp_path):
     # test the csv io on design matrices
     tr = 1.0
     frametimes = np.linspace(0, 127 * tr, 128)
@@ -442,11 +444,10 @@ def test_csv_io():
     DM = make_dmtx(frametimes, paradigm, hrf_model='Canonical',
                    drift_model='polynomial', drift_order=3)
     path = 'dmtx.csv'
-    with InTemporaryDirectory():
-        DM.write_csv(path)
-        DM2 = dmtx_from_csv(path)
+    DM.write_csv(path)
+    DM2 = dmtx_from_csv(path)
     assert_almost_equal(DM.matrix, DM2.matrix)
-    assert_equal(DM.names, DM2.names)
+    assert DM.names == DM2.names
 
 
 def test_spm_1():
@@ -458,7 +459,7 @@ def test_spm_1():
     paradigm =  EventRelatedParadigm(conditions, onsets)
     X1 = make_dmtx(frametimes, paradigm, drift_model='blank')
     spm_dmtx = DMTX['arr_0']
-    assert_true(((spm_dmtx - X1.matrix) ** 2).sum() / (spm_dmtx ** 2).sum()
+    assert (((spm_dmtx - X1.matrix) ** 2).sum() / (spm_dmtx ** 2).sum()
                 < .1)
 
 
@@ -472,19 +473,15 @@ def test_spm_2():
     paradigm =  BlockParadigm(conditions, onsets, duration)
     X1 = make_dmtx(frametimes, paradigm, drift_model='blank')
     spm_dmtx = DMTX['arr_1']
-    assert_true(((spm_dmtx - X1.matrix) ** 2).sum() / (spm_dmtx ** 2).sum()
+    assert (((spm_dmtx - X1.matrix) ** 2).sum() / (spm_dmtx ** 2).sum()
                 < .1)
 
 
 def test_frametimes_as_a_list():
     # design matrix should work with frametimes provided as a list
     paradigm = basic_paradigm()
-    frametimes = list(range(0, 99))
+    frametimes = list(range(99))
     X1 = make_dmtx(frametimes, paradigm, drift_model='blank')
     frametimes = np.arange(0, 99)
     X2 = make_dmtx(frametimes, paradigm, drift_model='blank')
     assert_array_equal(X1.matrix, X2.matrix)
-
-if __name__ == "__main__":
-    import nose
-    nose.run(argv=['', __file__])
