@@ -37,7 +37,7 @@ def write_fake_fmri_data(shapes, rk=3, affine=np.eye(4)):
 def generate_fake_fmri_data(shapes, rk=3, affine=np.eye(4)):
     fmri_data = []
     design_matrices = []
-    for i, shape in enumerate(shapes):
+    for shape in shapes:
         data = 100 + np.random.randn(*shape)
         data[0] -= 10
         fmri_data.append(Nifti1Image(data, affine))
@@ -166,8 +166,8 @@ def test_glm_ar():
     mulm, n, p, q = ar1_glm()
     assert len(mulm.labels_) == n
     assert len(mulm.results_) > 1
-    tmp = sum([mulm.results_[key].theta.shape[1]
-               for key in mulm.results_])
+    tmp = sum(mulm.results_[key].theta.shape[1]
+               for key in mulm.results_)
     assert tmp == n
 
 
