@@ -2,7 +2,7 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """ This module defines some convenience functions of time.
 
-interp : an expresion for a interpolated function of time
+interp : an expression for a interpolated function of time
 
 linear_interp : an expression for a linearly interpolated function of
    time
@@ -17,22 +17,18 @@ convolve_functions : numerically convolve two functions of time
 
 fourier_basis : a convenience function to generate a Fourier basis
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 import itertools
 
 import numpy as np
-from scipy.interpolate import interp1d
-
 import sympy
+from scipy.interpolate import interp1d
 from sympy import DiracDelta, Symbol
 from sympy.utilities.lambdify import implemented_function, lambdify
 
-from nipy.algorithms.statistics.formula.formulae import Term, Formula
+from nipy.algorithms.statistics.formula.formulae import Formula, Term
 
 # Legacy repr printing from numpy.
-from nipy.testing import legacy_printing as setup_module  # noqa
 
 T = Term('t')
 
@@ -55,7 +51,7 @@ class Interp1dNumeric(interp1d):
     def __call__(self, x):
         if np.asarray(x).dtype.type == np.object_:
             raise TypeError('Object arrays not supported')
-        return super(Interp1dNumeric, self).__call__(x)
+        return super().__call__(x)
 
 
 def lambdify_t(expr):
@@ -95,8 +91,8 @@ def define(name, expr):
     --------
     >>> t = Term('t')
     >>> expr = t**2 + 3*t
-    >>> print(expr)  #doctest: +SYMPY_EQUAL
-    3*t + t**2
+    >>> expr
+    t**2 + 3*t
     >>> newexpr = define('f', expr)
     >>> print(newexpr)
     f(t)
@@ -140,13 +136,13 @@ def fourier_basis(freq):
     """
     r = []
     for f in freq:
-        r += [sympy.cos((2*sympy.pi*f*T)),
-              sympy.sin((2*sympy.pi*f*T))]
+        r += [sympy.cos(2*sympy.pi*f*T),
+              sympy.sin(2*sympy.pi*f*T)]
     return Formula(r)
 
 
 def interp(times, values, fill=0, name=None, **kw):
-    """ Generic interpolation function of t given `times` and `values`
+    r""" Generic interpolation function of t given `times` and `values`
 
     Imterpolator such that:
 
@@ -210,7 +206,7 @@ interp.counter = 0
 
 
 def linear_interp(times, values, fill=0, name=None, **kw):
-    """ Linear interpolation function of t given `times` and `values`
+    r""" Linear interpolation function of t given `times` and `values`
 
     Imterpolator such that:
 
@@ -433,7 +429,7 @@ def _conv_fx_gx(f_vals, g_vals, dt, min_f, min_g):
     return time, vals
 
 
-class TimeConvolver(object):
+class TimeConvolver:
     """ Make a convolution kernel from a symbolic function of t
 
     A convolution kernel is a function with extra attributes to allow it to
@@ -459,7 +455,7 @@ class TimeConvolver(object):
         self._vals = _eval_for(expr, self.support, self.delta)
 
     def convolve(self, g, g_interval, name=None, **kwargs):
-        """ Convolve sympy expression `g` with this kernel
+        r""" Convolve sympy expression `g` with this kernel
 
         Parameters
         ----------
@@ -492,7 +488,7 @@ class TimeConvolver(object):
 
 def convolve_functions(f, g, f_interval, g_interval, dt,
                        fill=0, name=None, **kwargs):
-    """ Expression containing numerical convolution of `fn1` with `fn2`
+    r""" Expression containing numerical convolution of `fn1` with `fn2`
 
     Parameters
     ----------
