@@ -1,10 +1,8 @@
-from __future__ import division, print_function, absolute_import
 
+import configparser
 import os
-import sys
 import subprocess
-
-from .externals.six.moves import configparser
+import sys
 
 COMMIT_INFO_FNAME = 'COMMIT_INFO.txt'
 
@@ -41,7 +39,7 @@ def pkg_commit_hash(pkg_path):
     # Try and get commit from written commit text file
     pth = os.path.join(pkg_path, COMMIT_INFO_FNAME)
     if not os.path.isfile(pth):
-        raise IOError('Missing commit info file %s' % pth)
+        raise OSError(f'Missing commit info file {pth}')
     cfg_parser = configparser.RawConfigParser()
     cfg_parser.read(pth)
     archive_subst = cfg_parser.get('commit hash', 'archive_subst_hash')
@@ -76,13 +74,14 @@ def get_pkg_info(pkg_path):
     '''
     src, hsh = pkg_commit_hash(pkg_path)
     import numpy
+
     import nipy
-    return dict(
-        pkg_path=pkg_path,
-        commit_source=src,
-        commit_hash=hsh,
-        sys_version=sys.version,
-        sys_executable=sys.executable,
-        sys_platform=sys.platform,
-        np_version=numpy.__version__,
-        nipy_version=nipy.__version__)
+    return {
+        'pkg_path': pkg_path,
+        'commit_source': src,
+        'commit_hash': hsh,
+        'sys_version': sys.version,
+        'sys_executable': sys.executable,
+        'sys_platform': sys.platform,
+        'np_version': numpy.__version__,
+        'nipy_version': nipy.__version__}
