@@ -17,7 +17,6 @@ if __name__ == '__main__':
     outdir = os.path.join('api','generated')
     docwriter = ApiDocWriter(package)
     docwriter.package_skip_patterns += [r'\.fixes$',
-                                        r'\.externals$',
                                         #r'\.labs\.viz',
                                         ]
     # XXX: Avoid nipy.modalities.fmri.aliased due to a bug in python2.6
@@ -25,4 +24,4 @@ if __name__ == '__main__':
                                         ]
     docwriter.write_api_docs(outdir)
     docwriter.write_index(outdir, 'gen', relative_to='api')
-    print('%d files written' % len(docwriter.written_modules))
+    print(f'{len(docwriter.written_modules)} files written')
